@@ -216,7 +216,8 @@ typedef	enum {RPC2_HOSTBYNAME = 39, RPC2_HOSTBYINETADDR = 17,
 	      RPC2_HOSTBYADDRINFO = 6, RPC2_DUMMYHOST=88888} HostTag;
 typedef	enum {RPC2_PORTBYINETNUMBER = 53, RPC2_PORTBYNAME = 64, 
 	      RPC2_DUMMYPORT = 99999} PortTag;
-typedef enum {RPC2_SUBSYSBYID = 71, RPC2_SUBSYSBYNAME = 84} SubsysTag;
+typedef enum {RPC2_SUBSYSBYID = 71, RPC2_SUBSYSBYNAME = 84,
+	      RPC2_DUMMYSUBSYS = 44444} SubsysTag;
 typedef	enum {RPC2_MGRPBYINETADDR = 111, RPC2_MGRPBYADDRINFO = 121,
 	      RPC2_MGRPBYNAME = 137, RPC2_DUMMYMGRP = 77777} MgrpTag;
 
@@ -249,6 +250,18 @@ extern long RPC2_Trace;
  */
 extern long RPC2_strict_ip_matching;
 
+/* The application can request a preferred minimal encryption key length
+ * The value is in bytes.
+ *
+ * AES_CCM uses three bytes of salt + AES key length, so useful values would be,
+ *   19 (128-bit AES key), 27 (192-bit AES key), or 35 (256-bit AES key).
+ *
+ * You can also set the environment variable 'RPC2_KEYSIZE', which is evaluated
+ * when RPC2_Init() is called, the environment variable can be set either in
+ * bytes or in bits. (19/152, 27/216, 35/280)
+ */
+extern size_t RPC2_Preferred_Keysize;
+extern int    RPC2_secure_only;
 
 /*
 ************************* Data Types known to RPGen ***********************
@@ -412,8 +425,9 @@ typedef struct RPC2_PacketBuffer {
 
 	/* these fields are set when we receive the packet. */
 	struct RPC2_addrinfo	*PeerAddr;
-	char   oldhostandport[88]; /* padding to keep the userspace interface
-				      mostly identical */
+	struct security_association *sa;
+	char   oldhostandport[84]; /* padding to keep the userspace interface
+				      mostly identical (on a 32-bit machine..)*/
 	struct timeval		RecvStamp;
     } Prefix;
 
@@ -476,11 +490,11 @@ typedef struct RPC2_PacketBuffer {
  * but SEFLAGS is. Second byte of Flags field is reserved for indicating
  * packet color by libfail. Third and fourth bytes are used as genuine RPC2
  * flags */
-#define RPC2_RETRY	0x1	/* set by runtime system */
-#define RPC2_ENCRYPTED	0x2	/* set by runtime system */
-#define	RPC2_MULTICAST	0x4	/* set by runtime system */
-
-#define	IsMulticast(pb)	((pb)->Header.Flags & RPC2_MULTICAST)
+#define RPC2_RETRY	0x01	/* set by runtime system */
+#define RPC2_ENCRYPTED	0x02	/* set by runtime system */
+/*      RPC2_MULTICAST  0x04	   Old multicast flag */
+/*      RPC2SEC_CAPABLE 0x08	   Old rpc2sec flag */
+#define RPC2SEC_CAPABLE	0x10	/* set on Init1 packet by new rpc2sec stack */
 
  /* Format of filter used in RPC2_GetRequest */
 
@@ -526,7 +540,8 @@ typedef
 	}
     RPC2_Options;
 
-#define RPC2_OPTION_IPV6 1
+#define RPC2_OPTION_IPV6	 0x1
+#define RPC2_OPTION_VERBOSE_INIT 0x2
 
 /* Structure for passing parameters to RPC2_NewBinding() and its multi clone */
 
