@@ -1,7 +1,7 @@
-/* A Bison parser, made by GNU Bison 1.875d.  */
+/* A Bison parser, made by GNU Bison 2.1.  */
 
 /* Skeleton parser for Yacc-like parsing with Bison,
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004 Free Software Foundation, Inc.
+   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -15,8 +15,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
-   Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.  */
+   Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.  */
 
 /* As a special exception, when this file is copied by Bison into a
    Bison output file, you may use that output file without restriction.
@@ -36,6 +36,9 @@
 /* Identify Bison output.  */
 #define YYBISON 1
 
+/* Bison version.  */
+#define YYBISON_VERSION "2.1"
+
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
 
@@ -70,6 +73,7 @@
      OUT = 272
    };
 #endif
+/* Tokens.  */
 #define IDENTIFIER 258
 #define NUMBER 259
 #define STRING 260
@@ -277,6 +281,11 @@ int next_opnum = 1;
 # define YYERROR_VERBOSE 0
 #endif
 
+/* Enabling the token table.  */
+#ifndef YYTOKEN_TABLE
+# define YYTOKEN_TABLE 0
+#endif
+
 #if ! defined (YYSTYPE) && ! defined (YYSTYPE_IS_DECLARED)
 #line 187 "rp2gen_parser.y"
 typedef union YYSTYPE {
@@ -292,8 +301,8 @@ typedef union YYSTYPE {
     VAR		***u_var_array_array;
     int         u_int;
 } YYSTYPE;
-/* Line 191 of yacc.c.  */
-#line 297 "rp2gen_parser.c"
+/* Line 196 of yacc.c.  */
+#line 306 "rp2gen_parser.c"
 # define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 # define YYSTYPE_IS_TRIVIAL 1
@@ -304,30 +313,49 @@ typedef union YYSTYPE {
 /* Copy the second part of user declarations.  */
 
 
-/* Line 214 of yacc.c.  */
-#line 309 "rp2gen_parser.c"
+/* Line 219 of yacc.c.  */
+#line 318 "rp2gen_parser.c"
+
+#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
+# define YYSIZE_T __SIZE_TYPE__
+#endif
+#if ! defined (YYSIZE_T) && defined (size_t)
+# define YYSIZE_T size_t
+#endif
+#if ! defined (YYSIZE_T) && (defined (__STDC__) || defined (__cplusplus))
+# include <stddef.h> /* INFRINGES ON USER NAME SPACE */
+# define YYSIZE_T size_t
+#endif
+#if ! defined (YYSIZE_T)
+# define YYSIZE_T unsigned int
+#endif
+
+#ifndef YY_
+# if YYENABLE_NLS
+#  if ENABLE_NLS
+#   include <libintl.h> /* INFRINGES ON USER NAME SPACE */
+#   define YY_(msgid) dgettext ("bison-runtime", msgid)
+#  endif
+# endif
+# ifndef YY_
+#  define YY_(msgid) msgid
+# endif
+#endif
 
 #if ! defined (yyoverflow) || YYERROR_VERBOSE
 
-# ifndef YYFREE
-#  define YYFREE free
-# endif
-# ifndef YYMALLOC
-#  define YYMALLOC malloc
-# endif
-
 /* The parser invokes alloca or malloc; define the necessary symbols.  */
 
 # ifdef YYSTACK_USE_ALLOCA
 #  if YYSTACK_USE_ALLOCA
-#   define YYSTACK_ALLOC alloca
-#  endif
-# else
-#  if defined (alloca) || defined (_ALLOCA_H)
-#   define YYSTACK_ALLOC alloca
-#  else
 #   ifdef __GNUC__
 #    define YYSTACK_ALLOC __builtin_alloca
+#   else
+#    define YYSTACK_ALLOC alloca
+#    if defined (__STDC__) || defined (__cplusplus)
+#     include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
+#     define YYINCLUDED_STDLIB_H
+#    endif
 #   endif
 #  endif
 # endif
@@ -335,13 +363,39 @@ typedef union YYSTYPE {
 # ifdef YYSTACK_ALLOC
    /* Pacify GCC's `empty if-body' warning. */
 #  define YYSTACK_FREE(Ptr) do { /* empty */; } while (0)
-# else
-#  if defined (__STDC__) || defined (__cplusplus)
-#   include <stdlib.h> /* INFRINGES ON USER NAME SPACE */
-#   define YYSIZE_T size_t
+#  ifndef YYSTACK_ALLOC_MAXIMUM
+    /* The OS might guarantee only one guard page at the bottom of the stack,
+       and a page size can be as small as 4096 bytes.  So we cannot safely
+       invoke alloca (N) if N exceeds 4096.  Use a slightly smaller number
+       to allow for a few compiler-allocated temporary stack slots.  */
+#   define YYSTACK_ALLOC_MAXIMUM 4032 /* reasonable circa 2005 */
 #  endif
+# else
 #  define YYSTACK_ALLOC YYMALLOC
 #  define YYSTACK_FREE YYFREE
+#  ifndef YYSTACK_ALLOC_MAXIMUM
+#   define YYSTACK_ALLOC_MAXIMUM ((YYSIZE_T) -1)
+#  endif
+#  ifdef __cplusplus
+extern "C" {
+#  endif
+#  ifndef YYMALLOC
+#   define YYMALLOC malloc
+#   if (! defined (malloc) && ! defined (YYINCLUDED_STDLIB_H) \
+	&& (defined (__STDC__) || defined (__cplusplus)))
+void *malloc (YYSIZE_T); /* INFRINGES ON USER NAME SPACE */
+#   endif
+#  endif
+#  ifndef YYFREE
+#   define YYFREE free
+#   if (! defined (free) && ! defined (YYINCLUDED_STDLIB_H) \
+	&& (defined (__STDC__) || defined (__cplusplus)))
+void free (void *); /* INFRINGES ON USER NAME SPACE */
+#   endif
+#  endif
+#  ifdef __cplusplus
+}
+#  endif
 # endif
 #endif /* ! defined (yyoverflow) || YYERROR_VERBOSE */
 
@@ -376,7 +430,7 @@ union yyalloc
 #   define YYCOPY(To, From, Count)		\
       do					\
 	{					\
-	  register YYSIZE_T yyi;		\
+	  YYSIZE_T yyi;				\
 	  for (yyi = 0; yyi < (Count); yyi++)	\
 	    (To)[yyi] = (From)[yyi];		\
 	}					\
@@ -426,7 +480,7 @@ union yyalloc
 #define YYUNDEFTOK  2
 #define YYMAXUTOK   272
 
-#define YYTRANSLATE(YYX) 						\
+#define YYTRANSLATE(YYX)						\
   ((unsigned int) (YYX) <= YYMAXUTOK ? yytranslate[YYX] : YYUNDEFTOK)
 
 /* YYTRANSLATE[YYLEX] -- Bison symbol number corresponding to YYLEX.  */
@@ -513,8 +567,8 @@ static const unsigned short int yyrline[] =
 };
 #endif
 
-#if YYDEBUG || YYERROR_VERBOSE
-/* YYTNME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
+#if YYDEBUG || YYERROR_VERBOSE || YYTOKEN_TABLE
+/* YYTNAME[SYMBOL-NUM] -- String name of the symbol SYMBOL-NUM.
    First, the terminals, then, starting at YYNTOKENS, nonterminals. */
 static const char *const yytname[] =
 {
@@ -678,22 +732,6 @@ static const unsigned char yystos[] =
       63,    56,    61,    18,    20
 };
 
-#if ! defined (YYSIZE_T) && defined (__SIZE_TYPE__)
-# define YYSIZE_T __SIZE_TYPE__
-#endif
-#if ! defined (YYSIZE_T) && defined (size_t)
-# define YYSIZE_T size_t
-#endif
-#if ! defined (YYSIZE_T)
-# if defined (__STDC__) || defined (__cplusplus)
-#  include <stddef.h> /* INFRINGES ON USER NAME SPACE */
-#  define YYSIZE_T size_t
-# endif
-#endif
-#if ! defined (YYSIZE_T)
-# define YYSIZE_T unsigned int
-#endif
-
 #define yyerrok		(yyerrstatus = 0)
 #define yyclearin	(yychar = YYEMPTY)
 #define YYEMPTY		(-2)
@@ -723,26 +761,59 @@ do								\
       goto yybackup;						\
     }								\
   else								\
-    { 								\
-      yyerror ("syntax error: cannot back up");\
+    {								\
+      yyerror (YY_("syntax error: cannot back up")); \
       YYERROR;							\
     }								\
 while (0)
 
+
 #define YYTERROR	1
 #define YYERRCODE	256
 
-/* YYLLOC_DEFAULT -- Compute the default location (before the actions
-   are run).  */
 
+/* YYLLOC_DEFAULT -- Set CURRENT to span from RHS[1] to RHS[N].
+   If N is 0, then set CURRENT to the empty location which ends
+   the previous symbol: RHS[0] (always defined).  */
+
+#define YYRHSLOC(Rhs, K) ((Rhs)[K])
 #ifndef YYLLOC_DEFAULT
-# define YYLLOC_DEFAULT(Current, Rhs, N)		\
-   ((Current).first_line   = (Rhs)[1].first_line,	\
-    (Current).first_column = (Rhs)[1].first_column,	\
-    (Current).last_line    = (Rhs)[N].last_line,	\
-    (Current).last_column  = (Rhs)[N].last_column)
+# define YYLLOC_DEFAULT(Current, Rhs, N)				\
+    do									\
+      if (N)								\
+	{								\
+	  (Current).first_line   = YYRHSLOC (Rhs, 1).first_line;	\
+	  (Current).first_column = YYRHSLOC (Rhs, 1).first_column;	\
+	  (Current).last_line    = YYRHSLOC (Rhs, N).last_line;		\
+	  (Current).last_column  = YYRHSLOC (Rhs, N).last_column;	\
+	}								\
+      else								\
+	{								\
+	  (Current).first_line   = (Current).last_line   =		\
+	    YYRHSLOC (Rhs, 0).last_line;				\
+	  (Current).first_column = (Current).last_column =		\
+	    YYRHSLOC (Rhs, 0).last_column;				\
+	}								\
+    while (0)
 #endif
 
+
+/* YY_LOCATION_PRINT -- Print the location on the stream.
+   This macro was not mandated originally: define only if we know
+   we won't break user code: when these are the locations we know.  */
+
+#ifndef YY_LOCATION_PRINT
+# if YYLTYPE_IS_TRIVIAL
+#  define YY_LOCATION_PRINT(File, Loc)			\
+     fprintf (File, "%d.%d-%d.%d",			\
+              (Loc).first_line, (Loc).first_column,	\
+              (Loc).last_line,  (Loc).last_column)
+# else
+#  define YY_LOCATION_PRINT(File, Loc) ((void) 0)
+# endif
+#endif
+
+
 /* YYLEX -- calling `yylex' with the right arguments.  */
 
 #ifdef YYLEX_PARAM
@@ -765,19 +836,13 @@ do {						\
     YYFPRINTF Args;				\
 } while (0)
 
-# define YYDSYMPRINT(Args)			\
-do {						\
-  if (yydebug)					\
-    yysymprint Args;				\
-} while (0)
-
-# define YYDSYMPRINTF(Title, Token, Value, Location)		\
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)		\
 do {								\
   if (yydebug)							\
     {								\
       YYFPRINTF (stderr, "%s ", Title);				\
-      yysymprint (stderr, 					\
-                  Token, Value);	\
+      yysymprint (stderr,					\
+                  Type, Value);	\
       YYFPRINTF (stderr, "\n");					\
     }								\
 } while (0)
@@ -824,13 +889,13 @@ yy_reduce_print (yyrule)
 #endif
 {
   int yyi;
-  unsigned int yylno = yyrline[yyrule];
-  YYFPRINTF (stderr, "Reducing stack by rule %d (line %u), ",
+  unsigned long int yylno = yyrline[yyrule];
+  YYFPRINTF (stderr, "Reducing stack by rule %d (line %lu), ",
              yyrule - 1, yylno);
   /* Print the symbols being reduced, and their result.  */
   for (yyi = yyprhs[yyrule]; 0 <= yyrhs[yyi]; yyi++)
-    YYFPRINTF (stderr, "%s ", yytname [yyrhs[yyi]]);
-  YYFPRINTF (stderr, "-> %s\n", yytname [yyr1[yyrule]]);
+    YYFPRINTF (stderr, "%s ", yytname[yyrhs[yyi]]);
+  YYFPRINTF (stderr, "-> %s\n", yytname[yyr1[yyrule]]);
 }
 
 # define YY_REDUCE_PRINT(Rule)		\
@@ -844,8 +909,7 @@ do {					\
 int yydebug;
 #else /* !YYDEBUG */
 # define YYDPRINTF(Args)
-# define YYDSYMPRINT(Args)
-# define YYDSYMPRINTF(Title, Token, Value, Location)
+# define YY_SYMBOL_PRINT(Title, Type, Value, Location)
 # define YY_STACK_PRINT(Bottom, Top)
 # define YY_REDUCE_PRINT(Rule)
 #endif /* !YYDEBUG */
@@ -860,13 +924,9 @@ int yydebug;
    if the built-in stack extension method is used).
 
    Do not make this value too large; the results are undefined if
-   SIZE_MAX < YYSTACK_BYTES (YYMAXDEPTH)
+   YYSTACK_ALLOC_MAXIMUM < YYSTACK_BYTES (YYMAXDEPTH)
    evaluated with infinite-precision integer arithmetic.  */
 
-#if defined (YYMAXDEPTH) && YYMAXDEPTH == 0
-# undef YYMAXDEPTH
-#endif
-
 #ifndef YYMAXDEPTH
 # define YYMAXDEPTH 10000
 #endif
@@ -888,7 +948,7 @@ yystrlen (yystr)
      const char *yystr;
 #   endif
 {
-  register const char *yys = yystr;
+  const char *yys = yystr;
 
   while (*yys++ != '\0')
     continue;
@@ -913,8 +973,8 @@ yystpcpy (yydest, yysrc)
      const char *yysrc;
 #   endif
 {
-  register char *yyd = yydest;
-  register const char *yys = yysrc;
+  char *yyd = yydest;
+  const char *yys = yysrc;
 
   while ((*yyd++ = *yys++) != '\0')
     continue;
@@ -924,7 +984,55 @@ yystpcpy (yydest, yysrc)
 #  endif
 # endif
 
-#endif /* !YYERROR_VERBOSE */
+# ifndef yytnamerr
+/* Copy to YYRES the contents of YYSTR after stripping away unnecessary
+   quotes and backslashes, so that it's suitable for yyerror.  The
+   heuristic is that double-quoting is unnecessary unless the string
+   contains an apostrophe, a comma, or backslash (other than
+   backslash-backslash).  YYSTR is taken from yytname.  If YYRES is
+   null, do not copy; instead, return the length of what the result
+   would have been.  */
+static YYSIZE_T
+yytnamerr (char *yyres, const char *yystr)
+{
+  if (*yystr == '"')
+    {
+      size_t yyn = 0;
+      char const *yyp = yystr;
+
+      for (;;)
+	switch (*++yyp)
+	  {
+	  case '\'':
+	  case ',':
+	    goto do_not_strip_quotes;
+
+	  case '\\':
+	    if (*++yyp != '\\')
+	      goto do_not_strip_quotes;
+	    /* Fall through.  */
+	  default:
+	    if (yyres)
+	      yyres[yyn] = *yyp;
+	    yyn++;
+	    break;
+
+	  case '"':
+	    if (yyres)
+	      yyres[yyn] = '\0';
+	    return yyn;
+	  }
+    do_not_strip_quotes: ;
+    }
+
+  if (! yyres)
+    return yystrlen (yystr);
+
+  return yystpcpy (yyres, yystr) - yyres;
+}
+# endif
+
+#endif /* YYERROR_VERBOSE */
 
 
 
@@ -948,15 +1056,15 @@ yysymprint (yyoutput, yytype, yyvaluep)
   (void) yyvaluep;
 
   if (yytype < YYNTOKENS)
-    {
-      YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
-# ifdef YYPRINT
-      YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
-# endif
-    }
+    YYFPRINTF (yyoutput, "token %s (", yytname[yytype]);
   else
     YYFPRINTF (yyoutput, "nterm %s (", yytname[yytype]);
 
+
+# ifdef YYPRINT
+  if (yytype < YYNTOKENS)
+    YYPRINT (yyoutput, yytoknum[yytype], *yyvaluep);
+# endif
   switch (yytype)
     {
       default:
@@ -972,10 +1080,11 @@ yysymprint (yyoutput, yytype, yyvaluep)
 
 #if defined (__STDC__) || defined (__cplusplus)
 static void
-yydestruct (int yytype, YYSTYPE *yyvaluep)
+yydestruct (const char *yymsg, int yytype, YYSTYPE *yyvaluep)
 #else
 static void
-yydestruct (yytype, yyvaluep)
+yydestruct (yymsg, yytype, yyvaluep)
+    const char *yymsg;
     int yytype;
     YYSTYPE *yyvaluep;
 #endif
@@ -983,6 +1092,10 @@ yydestruct (yytype, yyvaluep)
   /* Pacify ``unused variable'' warnings.  */
   (void) yyvaluep;
 
+  if (!yymsg)
+    yymsg = "Deleting";
+  YY_SYMBOL_PRINT (yymsg, yytype, yyvaluep, yylocationp);
+
   switch (yytype)
     {
 
@@ -1010,10 +1123,10 @@ int yyparse ();
 
 
 
-/* The lookahead symbol.  */
+/* The look-ahead symbol.  */
 int yychar;
 
-/* The semantic value of the lookahead symbol.  */
+/* The semantic value of the look-ahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1039,17 +1152,17 @@ yyparse (void)
 #else
 int
 yyparse ()
-
+    ;
 #endif
 #endif
 {
   
-  register int yystate;
-  register int yyn;
+  int yystate;
+  int yyn;
   int yyresult;
   /* Number of tokens to shift before error messages enabled.  */
   int yyerrstatus;
-  /* Lookahead token as an internal (translated) token number.  */
+  /* Look-ahead token as an internal (translated) token number.  */
   int yytoken = 0;
 
   /* Three stacks and their tools:
@@ -1063,12 +1176,12 @@ yyparse ()
   /* The state stack.  */
   short int yyssa[YYINITDEPTH];
   short int *yyss = yyssa;
-  register short int *yyssp;
+  short int *yyssp;
 
   /* The semantic value stack.  */
   YYSTYPE yyvsa[YYINITDEPTH];
   YYSTYPE *yyvs = yyvsa;
-  register YYSTYPE *yyvsp;
+  YYSTYPE *yyvsp;
 
 
 
@@ -1100,7 +1213,6 @@ yyparse ()
   yyssp = yyss;
   yyvsp = yyvs;
 
-
   goto yysetstate;
 
 /*------------------------------------------------------------.
@@ -1133,7 +1245,7 @@ yyparse ()
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
 	   be undefined if yyoverflow is a macro.  */
-	yyoverflow ("parser stack overflow",
+	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
 
@@ -1144,11 +1256,11 @@ yyparse ()
       }
 #else /* no yyoverflow */
 # ifndef YYSTACK_RELOCATE
-      goto yyoverflowlab;
+      goto yyexhaustedlab;
 # else
       /* Extend the stack our own way.  */
       if (YYMAXDEPTH <= yystacksize)
-	goto yyoverflowlab;
+	goto yyexhaustedlab;
       yystacksize *= 2;
       if (YYMAXDEPTH < yystacksize)
 	yystacksize = YYMAXDEPTH;
@@ -1158,7 +1270,7 @@ yyparse ()
 	union yyalloc *yyptr =
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
-	  goto yyoverflowlab;
+	  goto yyexhaustedlab;
 	YYSTACK_RELOCATE (yyss);
 	YYSTACK_RELOCATE (yyvs);
 
@@ -1190,18 +1302,18 @@ yyparse ()
 yybackup:
 
 /* Do appropriate processing given the current state.  */
-/* Read a lookahead token if we need one and don't already have one.  */
+/* Read a look-ahead token if we need one and don't already have one.  */
 /* yyresume: */
 
-  /* First try to decide what to do without reference to lookahead token.  */
+  /* First try to decide what to do without reference to look-ahead token.  */
 
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a lookahead token if don't already have one.  */
+  /* Not known => get a look-ahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1216,7 +1328,7 @@ yybackup:
   else
     {
       yytoken = YYTRANSLATE (yychar);
-      YYDSYMPRINTF ("Next token is", yytoken, &yylval, &yylloc);
+      YY_SYMBOL_PRINT ("Next token is", yytoken, &yylval, &yylloc);
     }
 
   /* If the proper action on seeing token YYTOKEN is to reduce or to
@@ -1236,8 +1348,8 @@ yybackup:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  /* Shift the lookahead token.  */
-  YYDPRINTF ((stderr, "Shifting token %s, ", yytname[yytoken]));
+  /* Shift the look-ahead token.  */
+  YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
   /* Discard the token being shifted unless it is eof.  */
   if (yychar != YYEOF)
@@ -1290,7 +1402,7 @@ yyreduce:
 #line 236 "rp2gen_parser.y"
     {
 					    extern char *server_prefix;
-					    server_prefix = copy(yyvsp[-1].u_string+1);
+					    server_prefix = copy((yyvsp[-1].u_string)+1);
 					    server_prefix[strlen(server_prefix)-1] = '\0';
 					}
     break;
@@ -1299,7 +1411,7 @@ yyreduce:
 #line 242 "rp2gen_parser.y"
     {
 					    extern char *client_prefix;
-					    client_prefix = copy(yyvsp[-1].u_string+1);
+					    client_prefix = copy((yyvsp[-1].u_string)+1);
 					    client_prefix[strlen(client_prefix)-1] = '\0';
 					}
     break;
@@ -1307,7 +1419,7 @@ yyreduce:
   case 8:
 #line 250 "rp2gen_parser.y"
     {
-					    subsystem.subsystem_name = copy(yyvsp[-2].u_string+1);
+					    subsystem.subsystem_name = copy((yyvsp[-2].u_string)+1);
 					    subsystem.subsystem_name[strlen(subsystem.subsystem_name)-1] = '\0';
 					}
     break;
@@ -1327,22 +1439,22 @@ yyreduce:
 
   case 12:
 #line 267 "rp2gen_parser.y"
-    { yyval.u_string = yyvsp[0].u_string; }
+    { (yyval.u_string) = (yyvsp[0].u_string); }
     break;
 
   case 13:
 #line 271 "rp2gen_parser.y"
-    { yyval.u_string = yyvsp[0].u_string; }
+    { (yyval.u_string) = (yyvsp[0].u_string); }
     break;
 
   case 14:
 #line 275 "rp2gen_parser.y"
-    { yyval.u_string = yyvsp[0].u_string; }
+    { (yyval.u_string) = (yyvsp[0].u_string); }
     break;
 
   case 15:
 #line 279 "rp2gen_parser.y"
-    { subsystem.timeout = yyvsp[-2].u_string; }
+    { subsystem.timeout = (yyvsp[-2].u_string); }
     break;
 
   case 16:
@@ -1357,51 +1469,51 @@ yyreduce:
 
   case 22:
 #line 295 "rp2gen_parser.y"
-    { if (yyvsp[-2].u_bool) spit_define(yyvsp[-1].u_string, yyvsp[0].u_string); }
+    { if ((yyvsp[-2].u_bool)) spit_define((yyvsp[-1].u_string), (yyvsp[0].u_string)); }
     break;
 
   case 23:
 #line 297 "rp2gen_parser.y"
-    { if (yyvsp[-2].u_bool) spit_define(yyvsp[-1].u_string, yyvsp[0].u_string); }
+    { if ((yyvsp[-2].u_bool)) spit_define((yyvsp[-1].u_string), (yyvsp[0].u_string)); }
     break;
 
   case 24:
 #line 301 "rp2gen_parser.y"
     {
 					    extern void spit_type();
-					    yyvsp[-3].u_entry -> name = yyvsp[-2].u_string;
-					    yyvsp[-3].u_entry -> bound = yyvsp[-1].u_string;
-					    if (yyvsp[-3].u_entry->bound != NIL && yyvsp[-3].u_entry->type->tag != RPC2_BYTE_TAG) {
+					    (yyvsp[-3].u_entry) -> name = (yyvsp[-2].u_string);
+					    (yyvsp[-3].u_entry) -> bound = (yyvsp[-1].u_string);
+					    if ((yyvsp[-3].u_entry)->bound != NIL && (yyvsp[-3].u_entry)->type->tag != RPC2_BYTE_TAG) {
 						printf("RP2GEN: array type unimplemented: %s\n",
-						       yyvsp[-2].u_string);
+						       (yyvsp[-2].u_string));
 						exit(1);
 					    }
-					    enter(yyvsp[-3].u_entry);
-					    if (yyvsp[-4].u_bool) spit_type(yyvsp[-3].u_entry);
+					    enter((yyvsp[-3].u_entry));
+					    if ((yyvsp[-4].u_bool)) spit_type((yyvsp[-3].u_entry));
 					}
     break;
 
   case 25:
 #line 316 "rp2gen_parser.y"
-    { yyval.u_entry = make_entry(yyvsp[0].u_entry->type, yyvsp[0].u_entry); }
+    { (yyval.u_entry) = make_entry((yyvsp[0].u_entry)->type, (yyvsp[0].u_entry)); }
     break;
 
   case 26:
 #line 318 "rp2gen_parser.y"
-    { yyval.u_entry = make_entry(yyvsp[0].u_rpc2_type, NIL); }
+    { (yyval.u_entry) = make_entry((yyvsp[0].u_rpc2_type), NIL); }
     break;
 
   case 27:
 #line 320 "rp2gen_parser.y"
-    { yyval.u_entry = make_entry(yyvsp[0].u_rpc2_type, NIL); }
+    { (yyval.u_entry) = make_entry((yyvsp[0].u_rpc2_type), NIL); }
     break;
 
   case 28:
 #line 324 "rp2gen_parser.y"
     {
-					    yyval.u_entry = find(yyvsp[0].u_string);
-					    if (yyval.u_entry == NIL) {
-						printf("RP2GEN: can't find type: %s\n", yyvsp[0].u_string);
+					    (yyval.u_entry) = find((yyvsp[0].u_string));
+					    if ((yyval.u_entry) == NIL) {
+						printf("RP2GEN: can't find type: %s\n", (yyvsp[0].u_string));
 						exit(1);
 					    }
 					}
@@ -1409,7 +1521,7 @@ yyreduce:
 
   case 29:
 #line 334 "rp2gen_parser.y"
-    { yyval.u_rpc2_type = rpc2_struct_type(make_var_array()); }
+    { (yyval.u_rpc2_type) = rpc2_struct_type(make_var_array()); }
     break;
 
   case 30:
@@ -1419,14 +1531,14 @@ yyreduce:
 						printf("RP2GEN: too many fields: %d\n", MAX_VARS);
 						exit(1);
 					    }
-					    var_list.vars[var_list.counter++] = yyvsp[-1].u_var_array;
+					    var_list.vars[var_list.counter++] = (yyvsp[-1].u_var_array);
 					}
     break;
 
   case 31:
 #line 346 "rp2gen_parser.y"
     {
-					    var_list.vars[0] = yyvsp[0].u_var_array;
+					    var_list.vars[0] = (yyvsp[0].u_var_array);
 					    var_list.counter = 1;
 					}
     break;
@@ -1436,18 +1548,18 @@ yyreduce:
     {
 					    register char **id;
 					    register VAR **p;
-					    yyval.u_var_array = (VAR **) calloc(length(yyvsp[-1].u_string_array)+1, sizeof(VAR *));
-					    if (yyval.u_var_array == NIL) no_storage("field");
-					    for (id=yyvsp[-1].u_string_array, p=yyval.u_var_array; *id!=NIL; id++, p++)
-						*p = make_var(*id, NO_MODE, yyvsp[-2].u_entry);
+					    (yyval.u_var_array) = (VAR **) calloc(length((yyvsp[-1].u_string_array))+1, sizeof(VAR *));
+					    if ((yyval.u_var_array) == NIL) no_storage("field");
+					    for (id=(yyvsp[-1].u_string_array), p=(yyval.u_var_array); *id!=NIL; id++, p++)
+						*p = make_var(*id, NO_MODE, (yyvsp[-2].u_entry));
 					    *p = NIL;
-					    free(yyvsp[-1].u_string_array);
+					    free((yyvsp[-1].u_string_array));
 					}
     break;
 
   case 33:
 #line 366 "rp2gen_parser.y"
-    { yyval.u_string_array = make_id_array(); }
+    { (yyval.u_string_array) = make_id_array(); }
     break;
 
   case 34:
@@ -1457,21 +1569,21 @@ yyreduce:
 						printf("RP2GEN: too many identifiers in list: %d\n", MAX_IDS);
 						exit(1);
 					    }
-					    id_list.ids[id_list.counter++] = yyvsp[-2].u_string;
+					    id_list.ids[id_list.counter++] = (yyvsp[-2].u_string);
 					}
     break;
 
   case 35:
 #line 378 "rp2gen_parser.y"
     {
-					    id_list.ids[0] = yyvsp[0].u_string;
+					    id_list.ids[0] = (yyvsp[0].u_string);
 					    id_list.counter = 1;
 					}
     break;
 
   case 36:
 #line 385 "rp2gen_parser.y"
-    { yyval.u_rpc2_type = rpc2_enum_type(make_enum_array()); }
+    { (yyval.u_rpc2_type) = rpc2_enum_type(make_enum_array()); }
     break;
 
   case 37:
@@ -1481,67 +1593,67 @@ yyreduce:
 						printf("RP2GEN: too many enum values: %d\n", MAX_ENUMS);
 						exit(1);
 					    }
-					    enum_list.enums[enum_list.counter++] = yyvsp[-2].u_enum;
+					    enum_list.enums[enum_list.counter++] = (yyvsp[-2].u_enum);
 					}
     break;
 
   case 38:
 #line 397 "rp2gen_parser.y"
     {
-					    enum_list.enums[0] = yyvsp[0].u_enum;
+					    enum_list.enums[0] = (yyvsp[0].u_enum);
 					    enum_list.counter = 1;
 					}
     break;
 
   case 39:
 #line 404 "rp2gen_parser.y"
-    { yyval.u_enum = make_enum(yyvsp[-2].u_string, yyvsp[0].u_string); }
+    { (yyval.u_enum) = make_enum((yyvsp[-2].u_string), (yyvsp[0].u_string)); }
     break;
 
   case 40:
 #line 408 "rp2gen_parser.y"
-    { yyval.u_string = yyvsp[-1].u_string; }
+    { (yyval.u_string) = (yyvsp[-1].u_string); }
     break;
 
   case 41:
 #line 410 "rp2gen_parser.y"
-    { yyval.u_string = NIL; }
+    { (yyval.u_string) = NIL; }
     break;
 
   case 42:
 #line 414 "rp2gen_parser.y"
     {
-					    yyval.u_var = make_var(NIL, NO_MODE, find("RPC2_Integer"));
+					    (yyval.u_var) = make_var(NIL, NO_MODE, find("RPC2_Integer"));
 					}
     break;
 
   case 43:
 #line 418 "rp2gen_parser.y"
-    { yyval.u_var = NIL; }
+    { (yyval.u_var) = NIL; }
     break;
 
   case 44:
 #line 422 "rp2gen_parser.y"
-    { if (yyvsp[-1].u_bool == RP2_FALSE) {
-                                            if (yyvsp[-7].u_int == -1)
-                                                yyvsp[-7].u_int = next_opnum;
-                                            if (yyvsp[-7].u_int < next_opnum) {
+    { if ((yyvsp[-1].u_bool) == RP2_FALSE) {
+                                            if ((yyvsp[-7].u_int) == -1)
+                                                (yyvsp[-7].u_int) = next_opnum;
+                                            if ((yyvsp[-7].u_int) < next_opnum) {
                                               printf("RP2GEN: Opcode numbers must be always increasing\n");
                                               exit(1);
                                             }
-                                            next_opnum = yyvsp[-7].u_int + 1;
+                                            next_opnum = (yyvsp[-7].u_int) + 1;
                                           }
-					  insert(check_proc(make_proc(yyvsp[-7].u_int, yyvsp[-6].u_string, make_formal_array(), yyvsp[-2].u_string, yyvsp[-1].u_bool))); }
+					  insert(check_proc(make_proc((yyvsp[-7].u_int), (yyvsp[-6].u_string), make_formal_array(), (yyvsp[-2].u_string), (yyvsp[-1].u_bool)))); }
     break;
 
   case 45:
 #line 435 "rp2gen_parser.y"
-    { yyval.u_int = atoi(yyvsp[-1].u_string); }
+    { (yyval.u_int) = atoi((yyvsp[-1].u_string)); }
     break;
 
   case 46:
 #line 438 "rp2gen_parser.y"
-    { yyval.u_int = -1; }
+    { (yyval.u_int) = -1; }
     break;
 
   case 47:
@@ -1552,22 +1664,22 @@ yyreduce:
 						printf("RP2GEN: too many formals: %d\n", MAX_FORMALS);
 						exit(1);
 					    }
-					    formal_list.formals[formal_list.counter++] = yyvsp[-3].u_var;
-					    if (yyvsp[-2].u_var != NIL) {
+					    formal_list.formals[formal_list.counter++] = (yyvsp[-3].u_var);
+					    if ((yyvsp[-2].u_var) != NIL) {
 						if (formal_list.counter >= MAX_FORMALS) {
 						    printf("RP2GEN: too many formals: %d\n", MAX_FORMALS);
 						    exit(1);
 						}
-					        if (yyvsp[-3].u_var->type->type->tag != RPC2_STRUCT_TAG) {
-						    printf("RP2GEN: array type unimplemented: %s\n", yyvsp[-3].u_var->name);
+					        if ((yyvsp[-3].u_var)->type->type->tag != RPC2_STRUCT_TAG) {
+						    printf("RP2GEN: array type unimplemented: %s\n", (yyvsp[-3].u_var)->name);
 						    exit(1);
 					        } 
-					        formal_list.formals[formal_list.counter++] = yyvsp[-2].u_var;
-						yyvsp[-3].u_var->array = yyvsp[-2].u_var->name = createsize(yyvsp[-3].u_var->name);
-						yyvsp[-2].u_var->mode = yyvsp[-3].u_var->mode;
-						if (yyvsp[-3].u_var->mode != IN_MODE) { 
+					        formal_list.formals[formal_list.counter++] = (yyvsp[-2].u_var);
+						(yyvsp[-3].u_var)->array = (yyvsp[-2].u_var)->name = createsize((yyvsp[-3].u_var)->name);
+						(yyvsp[-2].u_var)->mode = (yyvsp[-3].u_var)->mode;
+						if ((yyvsp[-3].u_var)->mode != IN_MODE) { 
 						    maxvarp = make_var(NIL, NO_MODE, find("RPC2_Integer"));
-						    yyvsp[-3].u_var->arraymax = maxvarp->name = createmaxsize(yyvsp[-3].u_var->name);
+						    (yyvsp[-3].u_var)->arraymax = maxvarp->name = createmaxsize((yyvsp[-3].u_var)->name);
 						    maxvarp->mode = IN_MODE;
 						    formal_list.formals[formal_list.counter++] = maxvarp;
 						}
@@ -1579,20 +1691,20 @@ yyreduce:
 #line 471 "rp2gen_parser.y"
     {
 					    register VAR *maxvarp;
-					    formal_list.formals[0] = yyvsp[-1].u_var;
+					    formal_list.formals[0] = (yyvsp[-1].u_var);
 					    formal_list.counter = 1;
-					    if (yyvsp[0].u_var != NIL) {
-					        if (yyvsp[-1].u_var->type->type->tag != RPC2_STRUCT_TAG) {
+					    if ((yyvsp[0].u_var) != NIL) {
+					        if ((yyvsp[-1].u_var)->type->type->tag != RPC2_STRUCT_TAG) {
 						    printf("RP2GEN: array type unimplemented: %s\n",
-						           yyvsp[-1].u_var /* Is this a char *?*/);
+						           (yyvsp[-1].u_var) /* Is this a char *?*/);
 						    exit(1);
 					        } 
-					        formal_list.formals[formal_list.counter++] = yyvsp[0].u_var;
-						yyvsp[-1].u_var->array = yyvsp[0].u_var->name = createsize(yyvsp[-1].u_var->name);
-						yyvsp[0].u_var->mode = yyvsp[-1].u_var->mode;
-						if (yyvsp[-1].u_var->mode != IN_MODE) { 
+					        formal_list.formals[formal_list.counter++] = (yyvsp[0].u_var);
+						(yyvsp[-1].u_var)->array = (yyvsp[0].u_var)->name = createsize((yyvsp[-1].u_var)->name);
+						(yyvsp[0].u_var)->mode = (yyvsp[-1].u_var)->mode;
+						if ((yyvsp[-1].u_var)->mode != IN_MODE) { 
 						    maxvarp = make_var(NIL, NO_MODE, find("RPC2_Integer"));
-						    yyvsp[-1].u_var->arraymax = maxvarp->name = createmaxsize(yyvsp[-1].u_var->name);
+						    (yyvsp[-1].u_var)->arraymax = maxvarp->name = createmaxsize((yyvsp[-1].u_var)->name);
 						    maxvarp->mode = IN_MODE;
 						    formal_list.formals[formal_list.counter++] = maxvarp;
 						}
@@ -1609,65 +1721,66 @@ yyreduce:
   case 50:
 #line 498 "rp2gen_parser.y"
     {
-					  yyval.u_var = make_var(yyvsp[0].u_string, yyvsp[-2].u_mode, yyvsp[-1].u_entry);
+					  (yyval.u_var) = make_var((yyvsp[0].u_string), (yyvsp[-2].u_mode), (yyvsp[-1].u_entry));
 					}
     break;
 
   case 51:
 #line 504 "rp2gen_parser.y"
-    { yyval.u_mode = IN_MODE; }
+    { (yyval.u_mode) = IN_MODE; }
     break;
 
   case 52:
 #line 506 "rp2gen_parser.y"
-    { yyval.u_mode = OUT_MODE; }
+    { (yyval.u_mode) = OUT_MODE; }
     break;
 
   case 53:
 #line 508 "rp2gen_parser.y"
-    { yyval.u_mode = IN_OUT_MODE; }
+    { (yyval.u_mode) = IN_OUT_MODE; }
     break;
 
   case 54:
 #line 512 "rp2gen_parser.y"
-    { yyval.u_string = yyvsp[-1].u_string; }
+    { (yyval.u_string) = (yyvsp[-1].u_string); }
     break;
 
   case 55:
 #line 514 "rp2gen_parser.y"
-    { yyval.u_string = NIL; }
+    { (yyval.u_string) = NIL; }
     break;
 
   case 56:
 #line 518 "rp2gen_parser.y"
-    { yyval.u_bool = RP2_TRUE; }
+    { (yyval.u_bool) = RP2_TRUE; }
     break;
 
   case 57:
 #line 520 "rp2gen_parser.y"
-    { yyval.u_bool = RP2_FALSE; }
+    { (yyval.u_bool) = RP2_FALSE; }
     break;
 
   case 58:
 #line 524 "rp2gen_parser.y"
-    { yyval.u_string = yyvsp[0].u_string; }
+    { (yyval.u_string) = (yyvsp[0].u_string); }
     break;
 
   case 59:
 #line 526 "rp2gen_parser.y"
-    { yyval.u_string = yyvsp[0].u_string; }
+    { (yyval.u_string) = (yyvsp[0].u_string); }
     break;
 
   case 60:
 #line 530 "rp2gen_parser.y"
-    { yyval.u_string = yyvsp[0].u_string; }
+    { (yyval.u_string) = (yyvsp[0].u_string); }
     break;
 
 
+      default: break;
     }
 
-/* Line 1010 of yacc.c.  */
-#line 1671 "rp2gen_parser.c"
+/* Line 1126 of yacc.c.  */
+#line 1784 "rp2gen_parser.c"
 
   yyvsp -= yylen;
   yyssp -= yylen;
@@ -1706,12 +1819,36 @@ yyerrlab:
 
       if (YYPACT_NINF < yyn && yyn < YYLAST)
 	{
-	  YYSIZE_T yysize = 0;
 	  int yytype = YYTRANSLATE (yychar);
-	  const char* yyprefix;
-	  char *yymsg;
+	  YYSIZE_T yysize0 = yytnamerr (0, yytname[yytype]);
+	  YYSIZE_T yysize = yysize0;
+	  YYSIZE_T yysize1;
+	  int yysize_overflow = 0;
+	  char *yymsg = 0;
+#	  define YYERROR_VERBOSE_ARGS_MAXIMUM 5
+	  char const *yyarg[YYERROR_VERBOSE_ARGS_MAXIMUM];
 	  int yyx;
 
+#if 0
+	  /* This is so xgettext sees the translatable formats that are
+	     constructed on the fly.  */
+	  YY_("syntax error, unexpected %s");
+	  YY_("syntax error, unexpected %s, expecting %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s or %s");
+	  YY_("syntax error, unexpected %s, expecting %s or %s or %s or %s");
+#endif
+	  char *yyfmt;
+	  char const *yyf;
+	  static char const yyunexpected[] = "syntax error, unexpected %s";
+	  static char const yyexpecting[] = ", expecting %s";
+	  static char const yyor[] = " or %s";
+	  char yyformat[sizeof yyunexpected
+			+ sizeof yyexpecting - 1
+			+ ((YYERROR_VERBOSE_ARGS_MAXIMUM - 2)
+			   * (sizeof yyor - 1))];
+	  char const *yyprefix = yyexpecting;
+
 	  /* Start YYX at -YYN if negative to avoid negative indexes in
 	     YYCHECK.  */
 	  int yyxbegin = yyn < 0 ? -yyn : 0;
@@ -1719,81 +1856,91 @@ yyerrlab:
 	  /* Stay within bounds of both yycheck and yytname.  */
 	  int yychecklim = YYLAST - yyn;
 	  int yyxend = yychecklim < YYNTOKENS ? yychecklim : YYNTOKENS;
-	  int yycount = 0;
+	  int yycount = 1;
+
+	  yyarg[0] = yytname[yytype];
+	  yyfmt = yystpcpy (yyformat, yyunexpected);
 
-	  yyprefix = ", expecting ";
 	  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
 	    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
 	      {
-		yysize += yystrlen (yyprefix) + yystrlen (yytname [yyx]);
-		yycount += 1;
-		if (yycount == 5)
+		if (yycount == YYERROR_VERBOSE_ARGS_MAXIMUM)
 		  {
-		    yysize = 0;
+		    yycount = 1;
+		    yysize = yysize0;
+		    yyformat[sizeof yyunexpected - 1] = '\0';
 		    break;
 		  }
+		yyarg[yycount++] = yytname[yyx];
+		yysize1 = yysize + yytnamerr (0, yytname[yyx]);
+		yysize_overflow |= yysize1 < yysize;
+		yysize = yysize1;
+		yyfmt = yystpcpy (yyfmt, yyprefix);
+		yyprefix = yyor;
 	      }
-	  yysize += (sizeof ("syntax error, unexpected ")
-		     + yystrlen (yytname[yytype]));
-	  yymsg = (char *) YYSTACK_ALLOC (yysize);
-	  if (yymsg != 0)
-	    {
-	      char *yyp = yystpcpy (yymsg, "syntax error, unexpected ");
-	      yyp = yystpcpy (yyp, yytname[yytype]);
 
-	      if (yycount < 5)
+	  yyf = YY_(yyformat);
+	  yysize1 = yysize + yystrlen (yyf);
+	  yysize_overflow |= yysize1 < yysize;
+	  yysize = yysize1;
+
+	  if (!yysize_overflow && yysize <= YYSTACK_ALLOC_MAXIMUM)
+	    yymsg = (char *) YYSTACK_ALLOC (yysize);
+	  if (yymsg)
+	    {
+	      /* Avoid sprintf, as that infringes on the user's name space.
+		 Don't have undefined behavior even if the translation
+		 produced a string with the wrong number of "%s"s.  */
+	      char *yyp = yymsg;
+	      int yyi = 0;
+	      while ((*yyp = *yyf))
 		{
-		  yyprefix = ", expecting ";
-		  for (yyx = yyxbegin; yyx < yyxend; ++yyx)
-		    if (yycheck[yyx + yyn] == yyx && yyx != YYTERROR)
-		      {
-			yyp = yystpcpy (yyp, yyprefix);
-			yyp = yystpcpy (yyp, yytname[yyx]);
-			yyprefix = " or ";
-		      }
+		  if (*yyp == '%' && yyf[1] == 's' && yyi < yycount)
+		    {
+		      yyp += yytnamerr (yyp, yyarg[yyi++]);
+		      yyf += 2;
+		    }
+		  else
+		    {
+		      yyp++;
+		      yyf++;
+		    }
 		}
 	      yyerror (yymsg);
 	      YYSTACK_FREE (yymsg);
 	    }
 	  else
-	    yyerror ("syntax error; also virtual memory exhausted");
+	    {
+	      yyerror (YY_("syntax error"));
+	      goto yyexhaustedlab;
+	    }
 	}
       else
 #endif /* YYERROR_VERBOSE */
-	yyerror ("syntax error");
+	yyerror (YY_("syntax error"));
     }
 
 
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse lookahead token after an
+      /* If just tried and failed to reuse look-ahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
         {
-          /* If at end of input, pop the error token,
-	     then the rest of the stack, then return failure.  */
+	  /* Return failure if at end of input.  */
 	  if (yychar == YYEOF)
-	     for (;;)
-	       {
-		 YYPOPSTACK;
-		 if (yyssp == yyss)
-		   YYABORT;
-		 YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-		 yydestruct (yystos[*yyssp], yyvsp);
-	       }
+	    YYABORT;
         }
       else
 	{
-	  YYDSYMPRINTF ("Error: discarding", yytoken, &yylval, &yylloc);
-	  yydestruct (yytoken, &yylval);
+	  yydestruct ("Error: discarding", yytoken, &yylval);
 	  yychar = YYEMPTY;
-
 	}
     }
 
-  /* Else will try to reuse lookahead token after shifting the error
+  /* Else will try to reuse look-ahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1803,14 +1950,13 @@ yyerrlab:
 `---------------------------------------------------*/
 yyerrorlab:
 
-#ifdef __GNUC__
-  /* Pacify GCC when the user code never invokes YYERROR and the label
-     yyerrorlab therefore never appears in user code.  */
+  /* Pacify compilers like GCC when the user code never invokes
+     YYERROR and the label yyerrorlab therefore never appears in user
+     code.  */
   if (0)
      goto yyerrorlab;
-#endif
 
-  yyvsp -= yylen;
+yyvsp -= yylen;
   yyssp -= yylen;
   yystate = *yyssp;
   goto yyerrlab1;
@@ -1840,8 +1986,8 @@ yyerrlab1:
       if (yyssp == yyss)
 	YYABORT;
 
-      YYDSYMPRINTF ("Error: popping", yystos[*yyssp], yyvsp, yylsp);
-      yydestruct (yystos[yystate], yyvsp);
+
+      yydestruct ("Error: popping", yystos[yystate], yyvsp);
       YYPOPSTACK;
       yystate = *yyssp;
       YY_STACK_PRINT (yyss, yyssp);
@@ -1850,11 +1996,12 @@ yyerrlab1:
   if (yyn == YYFINAL)
     YYACCEPT;
 
-  YYDPRINTF ((stderr, "Shifting error token, "));
-
   *++yyvsp = yylval;
 
 
+  /* Shift the error token. */
+  YY_SYMBOL_PRINT ("Shifting", yystos[yyn], yyvsp, yylsp);
+
   yystate = yyn;
   goto yynewstate;
 
@@ -1874,16 +2021,25 @@ yyabortlab:
   goto yyreturn;
 
 #ifndef yyoverflow
-/*----------------------------------------------.
-| yyoverflowlab -- parser overflow comes here.  |
-`----------------------------------------------*/
-yyoverflowlab:
-  yyerror ("parser stack overflow");
+/*-------------------------------------------------.
+| yyexhaustedlab -- memory exhaustion comes here.  |
+`-------------------------------------------------*/
+yyexhaustedlab:
+  yyerror (YY_("memory exhausted"));
   yyresult = 2;
   /* Fall through.  */
 #endif
 
 yyreturn:
+  if (yychar != YYEOF && yychar != YYEMPTY)
+     yydestruct ("Cleanup: discarding lookahead",
+		 yytoken, &yylval);
+  while (yyssp != yyss)
+    {
+      yydestruct ("Cleanup: popping",
+		  yystos[*yyssp], yyvsp);
+      YYPOPSTACK;
+    }
 #ifndef yyoverflow
   if (yyss != yyssa)
     YYSTACK_FREE (yyss);
