@@ -149,7 +149,6 @@ struct MEntry *rpc2_AllocMgrp(struct RPC2_addrinfo *addr, RPC2_Handle handle)
     assert(me->MagicNumber == OBJ_MENTRY);
     me->ClientAddr = RPC2_copyaddrinfo(addr);
     me->MgroupID = mgrpid;
-    me->Flags = 0;
     me->SEProcs = NULL;
     me->SideEffectPtr = NULL;
     return(me);
@@ -197,9 +196,7 @@ void rpc2_FreeMgrp(me)
     /* why do we have 2 addrinfo structures? */
     if (me->ClientAddr)
 	RPC2_freeaddrinfo(me->ClientAddr);
-    if (me->IPMAddr)
-	RPC2_freeaddrinfo(me->IPMAddr);
-    me->ClientAddr = me->IPMAddr = NULL;
+    me->ClientAddr = NULL;
 
     rpc2_MoveEntry(&bucket->chain, &rpc2_MgrpFreeList, me, &bucket->count, &rpc2_MgrpFreeCount);
 }
@@ -245,29 +242,12 @@ long RPC2_CreateMgrp(OUT MgroupHandle, IN MulticastHost, IN MulticastPort, IN Su
     {
     struct MEntry	*me;
     long		secode;
-    RPC2_HostIdent Host;
 
     rpc2_Enter();
     say(0, RPC2_DebugLevel, "In RPC2_CreateMgrp()\n");
 
     TR_CREATEMGRP();
 
-    /* Validate the security parameters. */
-    switch ((int) SecurityLevel)
-	{
-	case RPC2_OPENKIMONO:
-		break;
-
-	case RPC2_AUTHONLY:
-	case RPC2_HEADERSONLY:
-	case RPC2_SECURE:
-		if ((EncryptionType & RPC2_ENCRYPTIONTYPES) == 0) rpc2_Quit(RPC2_FAIL); 	/* unknown encryption type */
-		if (MORETHANONEBITSET(EncryptionType)) rpc2_Quit(RPC2_FAIL);	/* tell me just one */
-		break;
-		
-	default:    rpc2_Quit(RPC2_FAIL);	/* bogus security level */
-	}
-
     /* Get an mgrp entry and initialize it. */
     me = rpc2_AllocMgrp(NULL, 0);
     assert(me != NULL);
@@ -277,71 +257,12 @@ long RPC2_CreateMgrp(OUT MgroupHandle, IN MulticastHost, IN MulticastPort, IN Su
     SetState(me, C_THINK);
     me->NextSeqNumber = 0;
 
-    me->SecurityLevel = SecurityLevel;
-    if (me->SecurityLevel == RPC2_OPENKIMONO) {
-	memset(me->SessionKey, 0, sizeof(RPC2_EncryptionKey));
-	me->EncryptionType = 0;
-    }
-    else {
-    	memcpy(me->SessionKey, SessionKey, sizeof(RPC2_EncryptionKey));
-    	me->EncryptionType = EncryptionType;
-    }
-
     me->listeners = (struct CEntry **)malloc(LISTENERALLOCSIZE*sizeof(struct CEntry *));
     assert(me->listeners != NULL);
     memset(me->listeners, 0, LISTENERALLOCSIZE*sizeof(struct CEntry *));
     me->howmanylisteners = 0;
     me->maxlisteners = LISTENERALLOCSIZE;
 
-    me->CurrentPacket = (RPC2_PacketBuffer *)NULL;
-
-    /* This is a bit useless as we really are not using actual multicast and
-     * the existing userspace code (venus) always passes 'INADDR_ANY'/2432.
-     * So this seems to be more of a place holder. */
-
-    /* any case, let's copy everything into a temporary HostIdent, so that we
-     * can throw it at the resolver. */
-    switch(MulticastHost->Tag) {
-    case RPC2_MGRPBYNAME:
-	Host.Tag = RPC2_HOSTBYNAME;
-	strcpy(Host.Value.Name, MulticastHost->Value.Name);
-	break;
-
-    case RPC2_MGRPBYINETADDR:
-	Host.Tag = RPC2_HOSTBYINETADDR;
-	/* struct assignment */
-	Host.Value.InetAddress = MulticastHost->Value.InetAddress;
-	break;
-
-    case RPC2_MGRPBYADDRINFO:
-	Host.Tag = RPC2_HOSTBYADDRINFO;
-	Host.Value.AddrInfo = MulticastHost->Value.AddrInfo;
-	break;
-
-    case RPC2_DUMMYMGRP:
-	Host.Tag = RPC2_DUMMYHOST;
-	break;
-    }
-
-    me->IPMAddr = rpc2_resolve(&Host, MulticastPort);
-    assert(me->IPMAddr);
-
-    /* XXX to avoid possible problems we probably should still truncate the
-     * list to the first returned address */
-    RPC2_freeaddrinfo(me->IPMAddr->ai_next);
-    me->IPMAddr->ai_next = NULL;
-
-    switch(Subsys->Tag)
-	{
-	case RPC2_SUBSYSBYID:
-	    me->SubsysId = Subsys->Value.SubsysId;
-	    break;
-
-	case RPC2_SUBSYSBYNAME:
-		say(-1, RPC2_DebugLevel, "RPC2_SUBSYSBYNAME has been banned\n");
-	default:    assert(FALSE);
-	}
-
     /* Obtain pointer to appropriate set of side effect routines */
     if (SideEffectType != 0)
 	{
@@ -429,19 +350,6 @@ say(0, RPC2_DebugLevel, "Enqueuing on connection %#x\n",ConnHandle);
 	say(0, RPC2_DebugLevel, "Dequeueing on connection %#x\n", ConnHandle);
 	}
 
-    /* Check that the connection's SubsysId matches that of the mgrp. */
-    if (me->SubsysId != ce->SubsysId)
-	rpc2_Quit(RPC2_BADMGROUP);
-
-    /* Check that the connection's security level and encryption type
-       match that of the mgrp. */
-    /* QUESTION: if both Mgroup and Connection security levels = open
-       kimono, should we bother checking that the Encryption Types are
-       equivalent? */
-    if ((me->SecurityLevel != ce->SecurityLevel) || 
-        (me->SecurityLevel != RPC2_OPENKIMONO && me->EncryptionType != ce->EncryptionType))
-	    rpc2_Quit(RPC2_BADMGROUP);
-    
     /* Check that the connection has the same side-effect type as the
        multicast group */
     if (me->SEProcs != ce->SEProcs)
@@ -457,15 +365,15 @@ say(0, RPC2_DebugLevel, "Enqueuing on connection %#x\n",ConnHandle);
     pb->Header.SeqNumber = ce->NextSeqNumber;
 
     imb = (struct InitMulticastBody *)pb->Body;
+    memset(imb, 0, sizeof(struct InitMulticastBody));
     imb->MgroupHandle = htonl(me->MgroupID);
     imb->InitialSeqNumber = htonl(me->NextSeqNumber);
-    memcpy(imb->SessionKey, me->SessionKey, sizeof(RPC2_EncryptionKey));
 
     /* Notify side-effect routine, if any */
     savedpkt = pb;
     if (me->SEProcs != NULL && me->SEProcs->SE_AddToMgrp != NULL){
 	    secode = (*me->SEProcs->SE_AddToMgrp)(MgroupHandle, ConnHandle, &pb);
-	    if (pb != savedpkt) 
+	    if (pb != savedpkt)
 		    RPC2_FreeBuffer(&savedpkt);	    /* free old buffer */
 	    if (secode != RPC2_SUCCESS) {
 		    RPC2_FreeBuffer(&pb);
@@ -688,70 +596,6 @@ long RPC2_DeleteMgrp(IN MgroupHandle)
     rpc2_Quit(RPC2_SUCCESS);
     }
 
-
-/* Either expand the MgroupHandle into the list of associated
-   connections, or validate the connections that were passed in,
-   whichever the caller has requested. */
-long SetupMulticast(MCast, meaddr, HowMany, ConnHandleList)
-    RPC2_Multicast  *MCast;
-    struct MEntry   **meaddr;
-    int		    HowMany;
-    RPC2_Handle	    ConnHandleList[];
-    {
-    struct MEntry   *me;
-    int		    i;
-
-    /* initialize out parameter in case of failure */
-    *meaddr = 0;
-
-    /* Validate multicast group. */
-    while (TRUE)
-	{
-	me = rpc2_GetMgrp(NULL, MCast->Mgroup, CLIENT);
-	if (me == NULL) return(RPC2_NOMGROUP);
-	if (TestState(me, CLIENT, C_HARDERROR)) rpc2_Quit(RPC2_FAIL);
-
-	if (TestState(me, CLIENT, C_THINK)) break;
-
-	/*  if (!EnqueueRequest) rpc2_Quit(RPC2_MGRPBUSY);*/
-	say(0, RPC2_DebugLevel, "Enqueuing on mgrp %#x\n", MCast->Mgroup);
-	LWP_WaitProcess((char *)me);
-	say(0, RPC2_DebugLevel, "Dequeueing on mgrp %#x\n", MCast->Mgroup);
-	}
-
-    assert(me->listeners != NULL && me->maxlisteners >= me->howmanylisteners);
-    if (me->howmanylisteners == 0) return(RPC2_BADMGROUP);
-    if (MCast->ExpandHandle)
-	{
-	if (me->howmanylisteners != HowMany) return(RPC2_BADMGROUP);
-	for (i = 0; i < me->howmanylisteners; i++)
-	    {
-	    assert(me->listeners[i]->Mgrp == me);
-	    ConnHandleList[i] = me->listeners[i]->UniqueCID;
-	    }
-	}
-    else
-	{
-	int count = 0;
-	for (i = 0; i < HowMany; i++)
-	    {
-	    struct CEntry *ce;
-
-	    if (ConnHandleList[i] == 0) continue;
-	    ce = rpc2_GetConn(ConnHandleList[i]);
-	    if (ce == NULL) return(RPC2_BADMGROUP);
-	    if (ce->Mgrp != me) return(RPC2_BADMGROUP);
-	    count++;
-	    }
-	if (me->howmanylisteners != count) return(RPC2_BADMGROUP);
-	}
-
-    SetState(me, C_AWAITREPLY);	    /* lock mgrp! */
-    *meaddr = me;
-    return(RPC2_SUCCESS);
-    }
-
-
 void HandleInitMulticast(RPC2_PacketBuffer *pb, struct CEntry *ce)
 {
     struct SL_Entry		*sl;
@@ -790,11 +634,7 @@ void HandleInitMulticast(RPC2_PacketBuffer *pb, struct CEntry *ce)
     me = rpc2_AllocMgrp(ce->HostInfo->Addr, imb->MgroupHandle);
     SetRole(me, SERVER);
     SetState(me, S_AWAITREQUEST);
-    me->SubsysId = ce->SubsysId;
     me->NextSeqNumber = imb->InitialSeqNumber;
-    me->SecurityLevel = ce->SecurityLevel;
-    memcpy(me->SessionKey, imb->SessionKey, sizeof(RPC2_EncryptionKey));
-    me->EncryptionType = ce->EncryptionType;
     me->conn = ce;
     ce->Mgrp = me;
     me->SEProcs = ce->SEProcs;
@@ -817,105 +657,6 @@ void HandleInitMulticast(RPC2_PacketBuffer *pb, struct CEntry *ce)
     rpc2_XmitPacket(pb, ce->HostInfo->Addr, 1);
 
     /* Save reply for retransmission. */
-    SavePacketForRetry(pb, ce);        
+    SavePacketForRetry(pb, ce);
 }
 
-
-int XlateMcastPacket(RPC2_PacketBuffer *pb)
-    {
-    struct MEntry  *me;
-    struct CEntry  *ce;
-    long    h_RemoteHandle = ntohl(pb->Header.RemoteHandle),
-	    h_LocalHandle = ntohl(pb->Header.LocalHandle),
-	    h_Flags = ntohl(pb->Header.Flags),
-	    h_SeqNumber;				/* decrypt first */
-    char addr[RPC2_ADDRSTRLEN];
-
-    say(9, RPC2_DebugLevel, "In XlateMcastPacket()\n");
-
-    TR_XLATEMCASTPACKET();
-
-    /* This is a hack that may have to be changed.  Packets which are initially
-       multicasted are sent on the point-to-point connection if and when they
-       are retried.  In order for a server to maintain its multicast sequence
-       number properly, it must be able to distinguish between retries on the
-       point-to-point connection that were initially multicast and those which
-       were not.  The hack currently adopted is to set the MULTICAST bit on 
-       retries which were initially multicasted, even though the retry packet
-       was not actually multicasted.  Obviously, this will not be sufficient
-       if we ever physically multicast retries. */
-    if (h_Flags & RPC2_RETRY) return(TRUE);	/* pass the packet untranslated */
-
-    /* Lookup the multicast connection handle. */
-    if (h_RemoteHandle == 0 || h_LocalHandle != 0) {
-	BOGUS(pb);
-	return FALSE;
-    }
-    me = rpc2_GetMgrp(pb->Prefix.PeerAddr, h_RemoteHandle, SERVER);
-    if (me == NULL) {BOGUS(pb); return(FALSE);}
-
-    assert(TestRole(me, SERVER));	/* redundant check */
-    ce = me->conn;
-    if (!ce || ce->Mgrp != me) {
-	BOGUS(pb);
-	return FALSE;
-    }
-    assert(TestRole(ce, SERVER));
-
-    /* Drop ANY multicast packet that is out of the ordinary. */
-    /* I suspect that only the checks on the me state and the me sequence
-       number (further down) are strictly necessary at this point, but we'll
-       be conservative for now. */
-    if (TestState(me, SERVER, ~S_AWAITREQUEST) ||
-        TestState(ce, SERVER, ~S_AWAITREQUEST) ||
-        (h_Flags & RPC2_RETRY) != 0) {BOGUS(pb); return(FALSE);}
-
-    RPC2_formataddrinfo(pb->Prefix.PeerAddr, addr, RPC2_ADDRSTRLEN);
-    say(9, RPC2_DebugLevel, "Host = %s\tMgrp = 0x%lx\n", addr, h_RemoteHandle);
-
-    /* Decrypt the packet with the MULTICAST session key. Clear the encrypted 
-       bit so that we don't decrypt again with the connection session key. */
-    if (h_Flags & RPC2_ENCRYPTED)
-	{
-	switch((int) me->SecurityLevel)
-	    {
-	    case RPC2_HEADERSONLY:
-		rpc2_Decrypt((char *)&pb->Header.BodyLength,
-				(char *)&pb->Header.BodyLength, 
-				sizeof(struct RPC2_PacketHeader)-4*sizeof(RPC2_Integer),
-				me->SessionKey, me->EncryptionType);
-		break;
-	
-	    case RPC2_SECURE:
-		rpc2_Decrypt(	(char *)&pb->Header.BodyLength,
-				(char *)&pb->Header.BodyLength, 
-				pb->Prefix.LengthOfPacket-4*sizeof(RPC2_Integer),
-				me->SessionKey, me->EncryptionType);
-		break;
-
-	    default:    break;
-	    }
-	pb->Header.Flags = htonl(h_Flags &= ~RPC2_ENCRYPTED);
-	}
-
-    /* Make sure that the incoming and our stored multicast sequence numbers 
-       agree.  If they do, transform the packet so that it will appear to have
-       arrived on the (point-to-point) connection. */
-    /* QUESTION: Don't we need some check here for MultiRpc packets ahead of
-       sequence analagous to that in DecodePacket()? */
-    h_SeqNumber = ntohl(pb->Header.SeqNumber);
-    if (me->NextSeqNumber != h_SeqNumber) {BOGUS(pb); return(FALSE);}
-    pb->Header.RemoteHandle = htonl(ce->UniqueCID);
-    pb->Header.LocalHandle = htonl(ce->PeerHandle);
-    pb->Header.SeqNumber = htonl(ce->NextSeqNumber);
-
-    /* We do NOT update the multicast connection state and sequence number here.
-       Instead, we leave the multicast flag-bit set so that routines which
-       update connection state and sequence numbers can do the same for the
-       multicast connection.  This avoids having to reverse the multicast state
-       if we later decide to NAK or drop the packet. */
-
-    say(9, RPC2_DebugLevel, "In XlateMcastPacket(): returning success\n");
-    return(TRUE);
-    }
-
