@@ -1,26 +1,25 @@
 /* BLURB lgpl
 
-                           Coda File System
-                              Release 5
+			Coda File System
+			    Release 5
 
-          Copyright (c) 1987-1999 Carnegie Mellon University
-                  Additional copyrights listed below
+	    Copyright (c) 1987-1999 Carnegie Mellon University
+		Additional copyrights listed below
 
 This  code  is  distributed "AS IS" without warranty of any kind under
 the  terms of the  GNU  Library General Public Licence  Version 2,  as
 shown in the file LICENSE. The technical and financial contributors to
 Coda are listed in the file CREDITS.
 
-                        Additional copyrights
-
+		    Additional copyrights
 #*/
 
 /*
-                         IBM COPYRIGHT NOTICE
+			IBM COPYRIGHT NOTICE
 
-                          Copyright (C) 1986
-             International Business Machines Corporation
-                         All Rights Reserved
+			Copyright (C) 1986
+	      International Business Machines Corporation
+			All Rights Reserved
 
 This  file  contains  some  code identical to or derived from the 1986
 version of the Andrew File System ("AFS"), which is owned by  the  IBM
@@ -51,6 +50,7 @@ Pittsburgh, PA.
 #include <assert.h>
 #include "rpc2.private.h"
 #include <rpc2/se.h>
+#include <rpc2/secure.h>
 #include "cbuf.h"
 #include "trace.h"
 
@@ -99,7 +99,7 @@ static long FailPacket(int (*predicate)(), RPC2_PacketBuffer *pb,
     sin = (struct sockaddr_in *)addr->ai_addr;
     inaddr = (unsigned char *)&sin->sin_addr;
 
-    ip1 = inaddr[0]; ip2 = inaddr[1]; ip3 = inaddr[2]; ip4 = inaddr[3]; 
+    ip1 = inaddr[0]; ip2 = inaddr[1]; ip3 = inaddr[2]; ip4 = inaddr[3];
 
     ntohPktColor(pb);
     color = GetPktColor(pb);
@@ -109,8 +109,10 @@ static long FailPacket(int (*predicate)(), RPC2_PacketBuffer *pb,
     return drop;
 }
 
-void rpc2_XmitPacket(IN RPC2_PacketBuffer *whichPB, IN struct RPC2_addrinfo *addr, int confirm)
+void rpc2_XmitPacket(RPC2_PacketBuffer *pb, struct RPC2_addrinfo *addr,
+		     int confirm)
 {
+    static int log_limit = 0;
     int whichSocket, n, flags = 0;
 
     say(0, RPC2_DebugLevel, "rpc2_XmitPacket()\n");
@@ -120,27 +122,14 @@ void rpc2_XmitPacket(IN RPC2_PacketBuffer *whichPB, IN struct RPC2_addrinfo *add
 	{
 	fprintf(rpc2_logfile, "\t");
 	rpc2_printaddrinfo(addr, rpc2_logfile);
+	if (pb->Prefix.sa && pb->Prefix.sa->encrypt)
+	    fprintf(rpc2_logfile, " (secure)");
 	fprintf(rpc2_logfile, "\n");
-	rpc2_PrintPacketHeader(whichPB, rpc2_logfile);
+	rpc2_PrintPacketHeader(pb, rpc2_logfile);
 	}
 #endif
 
-    assert(whichPB->Prefix.MagicNumber == OBJ_PACKETBUFFER);
-
-    TR_XMIT();
-
-    /* Only Internet for now; no name->number translation attempted */
-
-    if (ntohl(whichPB->Header.Flags) & RPC2_MULTICAST)
-    {
-	rpc2_MSent.Total++;
-	rpc2_MSent.Bytes += whichPB->Prefix.LengthOfPacket;
-    }
-    else
-    {
-	rpc2_Sent.Total++;
-	rpc2_Sent.Bytes += whichPB->Prefix.LengthOfPacket;
-    }
+    assert(pb->Prefix.MagicNumber == OBJ_PACKETBUFFER);
 
     whichSocket = rpc2_v6RequestSocket;
 
@@ -151,30 +140,23 @@ void rpc2_XmitPacket(IN RPC2_PacketBuffer *whichPB, IN struct RPC2_addrinfo *add
     if (whichSocket == -1)
 	return; // RPC2_NOCONNECTION
 
-    if (FailPacket(Fail_SendPredicate, whichPB, addr, whichSocket))
+    TR_XMIT();
+
+    /* Only Internet for now; no name->number translation attempted */
+
+    rpc2_Sent.Total++;
+    rpc2_Sent.Bytes += pb->Prefix.LengthOfPacket;
+
+    if (FailPacket(Fail_SendPredicate, pb, addr, whichSocket))
 	return;
 
     if (confirm)
 	flags = msg_confirm;
 
-    n = sendto(whichSocket, &whichPB->Header, whichPB->Prefix.LengthOfPacket,
-	       flags, addr->ai_addr, addr->ai_addrlen);
+    n = secure_sendto(whichSocket, &pb->Header,
+		      pb->Prefix.LengthOfPacket, flags,
+		      addr->ai_addr, addr->ai_addrlen, pb->Prefix.sa);
 
-#ifdef __linux__
-    if (n == -1 && errno == ECONNREFUSED)
-    {
-	/* On linux ECONNREFUSED is a result of a previous sendto
-	 * triggering an ICMP bad host/port response. This
-	 * behaviour seems to be required by RFC1122, but in
-	 * practice this is not implemented by other UDP stacks.
-	 * We retry the send, because the failing host was possibly
-	 * not the one we tried to send to this time. --JH
-	 */
-	n = sendto(whichSocket, &whichPB->Header,
-		   whichPB->Prefix.LengthOfPacket, 0,
-		   addr->ai_addr, addr->ai_addrlen);
-    } else
-#endif
     if (n == -1 && errno == EAGAIN)
     {
 	/* operation failed probably because the send buffer was full. we could
@@ -189,12 +171,35 @@ void rpc2_XmitPacket(IN RPC2_PacketBuffer *whichPB, IN struct RPC2_addrinfo *add
     }
     else
 
-    if (RPC2_Perror && n != whichPB->Prefix.LengthOfPacket)
+    if (RPC2_Perror && n != pb->Prefix.LengthOfPacket)
     {
 	char msg[100];
 	sprintf(msg, "Xmit_Packet socket %d", whichSocket);
 	perror(msg);
     }
+
+    /* Log outgoing packets that are larger than the IPv6 MTU
+     * (- ipv6 hdr, ipv6 fragment hdr, udp hdr, secure spi/seq/iv/icv)
+     *
+     * Only log the first 10 oversized packets and only when we know
+     * for sure that the headers are still unencrypted and thus, useful */
+    if (log_limit < 10 && pb->Prefix.sa &&
+	pb->Prefix.LengthOfPacket > (1280 - 40 - 8 - 8 - 24))
+    {
+	fprintf(rpc2_logfile,
+		"XMIT: Sent long packet (subsys %d, opcode %d, length %ld)\n",
+		ntohl(pb->Header.SubsysId), ntohl(pb->Header.Opcode),
+		pb->Prefix.LengthOfPacket);
+	fflush(rpc2_logfile);
+	log_limit++;
+    }
+
+}
+
+struct security_association *rpc2_GetSA(uint32_t spi)
+{
+    struct CEntry *ce= __rpc2_GetConn((RPC2_Handle)spi);
+    return ce ? &ce->sa : NULL;
 }
 
 /* Reads the next packet from whichSocket into whichBuff, sets its
@@ -205,22 +210,23 @@ void rpc2_XmitPacket(IN RPC2_PacketBuffer *whichPB, IN struct RPC2_addrinfo *add
    Note that whichBuff should at least be able to accomodate 1 byte
    more than the longest receivable packet.  Only Internet packets are
    dealt with currently.  */
-long rpc2_RecvPacket(IN long whichSocket, OUT RPC2_PacketBuffer *whichBuff) 
+long rpc2_RecvPacket(IN long whichSocket, OUT RPC2_PacketBuffer *whichBuff)
 {
     long rc, len;
     size_t fromlen;
-    struct sockaddr_storage sa;
+    struct sockaddr_storage ss;
 
     say(0, RPC2_DebugLevel, "rpc2_RecvPacket()\n");
     assert(whichBuff->Prefix.MagicNumber == OBJ_PACKETBUFFER);
 
     len = whichBuff->Prefix.BufferSize - (long)(&whichBuff->Header) + (long)(whichBuff);
     assert(len > 0);
-    
+
     /* WARNING: only Internet works; no warnings */
-    fromlen = sizeof(sa);
-    rc = recvfrom(whichSocket, &whichBuff->Header, len, 0,
-		  (struct sockaddr *) &sa, &fromlen);
+    fromlen = sizeof(ss);
+    rc = secure_recvfrom(whichSocket, &whichBuff->Header, len, 0,
+			 (struct sockaddr *) &ss, &fromlen,
+			 &whichBuff->Prefix.sa, rpc2_GetSA);
 
     if (rc < 0 && errno == EAGAIN) {
 	/* the packet might have had a corrupt udp checksum */
@@ -232,7 +238,7 @@ long rpc2_RecvPacket(IN long whichSocket, OUT RPC2_PacketBuffer *whichBuff)
     }
 
     whichBuff->Prefix.PeerAddr =
-	RPC2_allocaddrinfo((struct sockaddr *)&sa, fromlen,
+	RPC2_allocaddrinfo((struct sockaddr *)&ss, fromlen,
 			   SOCK_DGRAM, IPPROTO_UDP);
 
     TR_RECV();
@@ -247,11 +253,8 @@ long rpc2_RecvPacket(IN long whichSocket, OUT RPC2_PacketBuffer *whichBuff)
     whichBuff->Prefix.LengthOfPacket = rc;
 
     if (rc == len) {
-	    if (ntohl(whichBuff->Header.Flags) & RPC2_MULTICAST)
-		    rpc2_MRecvd.Giant++;
-	    else
-		    rpc2_Recvd.Giant++;
-	    return(-3);
+	rpc2_Recvd.Giant++;
+	return(-3);
     }
 
     /* Try to get an accurate arrival time estimate for this packet */
@@ -566,7 +569,7 @@ long rpc2_SendReliably(IN Conn, IN Sle, IN Packet, IN TimeOut)
 		rpc2_Sent.Retries += 1;
 		rpc2_XmitPacket(Packet, Conn->HostInfo->Addr, 0);
 		break;	/* switch */
-		
+
 	    default: assert(FALSE);
 	    }
 	}
@@ -630,13 +633,13 @@ void rpc2_InitPacket(RPC2_PacketBuffer *pb, struct CEntry *ce, long bodylen)
 	pb->Header.Lamport	= RPC2_LamportTime();
 	pb->Header.BodyLength   = bodylen;
 	pb->Prefix.LengthOfPacket = sizeof(struct RPC2_PacketHeader) + bodylen;
-	//pb->Prefix.PeerAddr   = NULL;
 	memset(&pb->Prefix.RecvStamp, 0, sizeof(struct timeval));
 	if (ce)	{
+		pb->Prefix.sa = &ce->sa;
 		pb->Header.RemoteHandle = ce->PeerHandle;
 		pb->Header.LocalHandle  = ce->UniqueCID;
 		pb->Header.SubsysId  = ce->SubsysId;
 		pb->Header.Uniquefier = ce->PeerUnique;
 		SetPktColor(pb, ce->Color);
-    	}
+	}
 }
