@@ -43,6 +43,7 @@ Pittsburgh, PA.
 #endif
 
 #include <stdio.h>
+#include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <sys/types.h>
@@ -59,6 +60,8 @@ Pittsburgh, PA.
 #include <errno.h>
 #include <assert.h>
 #include <sys/file.h>
+
+#include <rpc2/secure.h>
 #include "rpc2.private.h"
 #include <rpc2/se.h>
 #include "trace.h"
@@ -76,10 +79,13 @@ long RPC2_Init(char *VId,		/* magic version string */
 	       )
 {
     char *c;
-    long i, ctpid;
+    long i;
+    PROCESS ctpid;
     struct RPC2_addrinfo *rpc2_localaddrs;
     long rc1 = RPC2_NOCONNECTION, rc2, rc;
     short port = 0;
+    int verbose;
+    char *env;
 
     rpc2_logfile = stderr;
     rpc2_tracefile = stderr;
@@ -88,7 +94,7 @@ long RPC2_Init(char *VId,		/* magic version string */
     say(0, RPC2_DebugLevel, "RPC2_Init()\n");
     say(999, RPC2_DebugLevel, "Runtime system version: \"%s\"\n", RPC2_VERSION);
 
-    if (strcmp(VId, RPC2_VERSION) != 0) 
+    if (strcmp(VId, RPC2_VERSION) != 0)
     {
 	say(-1, RPC2_DebugLevel, "RPC2_Init(): Wrong RPC2 version\n");
 	rpc2_Quit (RPC2_WRONGVERSION);
@@ -100,6 +106,25 @@ long RPC2_Init(char *VId,		/* magic version string */
     if (Options && (Options->Flags & RPC2_OPTION_IPV6))
 	rpc2_ipv6ready = 1;
 
+    env = getenv("RPC2SEC_KEYSIZE");
+    if (env)
+	RPC2_Preferred_Keysize = atoi(env);
+    if (RPC2_Preferred_Keysize > 64)
+	RPC2_Preferred_Keysize /= 8;
+
+    /* Do we accept only secure connections, default is no. This can
+     * be enabled by setting the RPC2SEC_ONLY environment variable.
+     * (and forced as disabled by setting RPC2SEC_ONLY=0/false/no)
+     *
+     * At some point once every client and server is 'expected' to run
+     * rpc2-2.0 or later we can change the default behaviour to accept
+     * only secure connections. */
+    env = getenv("RPC2SEC_ONLY");
+    RPC2_secure_only = env && memchr("0fFnN", *env, 5) == NULL;
+
+    verbose = (Options && (Options->Flags & RPC2_OPTION_VERBOSE_INIT));
+    secure_init(verbose);
+
     rpc2_InitMgrp();
     rpc2_InitHost();
 
@@ -109,7 +134,7 @@ long RPC2_Init(char *VId,		/* magic version string */
 	say(-1, RPC2_DebugLevel, "RPC2_Init(): Couldn't get addrinfo for localhost!\n");
 	rpc2_Quit(RPC2_FAIL);
     }
-    
+
 #ifdef PF_INET6
     rc1 = rpc2_CreateIPSocket(PF_INET6, &rpc2_v6RequestSocket,
 			      rpc2_localaddrs, &port);
@@ -138,9 +163,6 @@ long RPC2_Init(char *VId,		/* magic version string */
 	rpc2_Quit(RPC2_FAIL);
     }
 
-    /* Initialize random number generation for sequence numbers */
-    rpc2_InitRandom();
-
     IOMGR_Initialize();
     TM_Init(&rpc2_TimerQueue);
 
@@ -161,8 +183,7 @@ long RPC2_Init(char *VId,		/* magic version string */
 		      c, &rpc2_SocketListenerPID);
 
     c = "ClockTick";
-    LWP_CreateProcess(rpc2_ClockTick, 16384, LWP_NORMAL_PRIORITY, NULL,
-		      c, (PROCESS *)&ctpid);
+    LWP_CreateProcess(rpc2_ClockTick, 16384, LWP_NORMAL_PRIORITY, NULL, c, &ctpid);
 
     if (rc != RPC2_SUCCESS)
 	say(-1, RPC2_DebugLevel, "RPC2_Init(): Exiting with error\n");
@@ -328,6 +349,7 @@ long rpc2_AllocBuffer(IN long MinBodySize, OUT RPC2_PacketBuffer **BuffPtr,
 	*BuffPtr = GetPacket(thissize);
 	assert(*BuffPtr);
 	assert((*BuffPtr)->Prefix.MagicNumber == OBJ_PACKETBUFFER);
+	(*BuffPtr)->Prefix.sa = NULL;
 
 	memset(&(*BuffPtr)->Header, 0, sizeof(struct RPC2_PacketHeader));
 	(*BuffPtr)->Header.BodyLength = MinBodySize;
