@@ -263,7 +263,6 @@ struct SFTP_Entry		/* per-connection data structure */
     long XferState;		/* {XferNotStarted,XferInProgress,XferAborted,XferCompleted} */
 
     /* Next block is multicast specific */
-    long UseMulticast;		/* TRUE iff multicast was requested in SFTP_MultiRPC1 call */
     long RepliedSinceLastSS;	/* TRUE iff {ACK,NAK,START} received since last invocation of SendStrategy */
     long McastersStarted;	/* number of individual conns participating */
     long McastersFinished;	/* number of participating conns which have finished */
@@ -277,7 +276,7 @@ struct SFTP_Entry		/* per-connection data structure */
 				   This is the most recent packet such that it and all earlier packets
 				   are known by me to have been received by the other side */
     long SendMostRecent;	/* SendMostRecent is the latest data packet we have sent out  */
-    unsigned long SendTheseBits[BITMASKWIDTH];	/* Bit pattern of packets in the range SendLastContig+1..SendMostRecent
+    unsigned int SendTheseBits[BITMASKWIDTH];	/* Bit pattern of packets in the range SendLastContig+1..SendMostRecent
 				   that have successfully been sent by me AND are known by me to have
 				   been received by other side */
     long SendAckLimit;          /* Highest data packet for which an ack has been requested. */
@@ -290,7 +289,7 @@ struct SFTP_Entry		/* per-connection data structure */
     unsigned long RequestTime;  /* arrival time of packet, to correct RTT
 				   estimates for processing time */
 
-    unsigned long RecvTheseBits[BITMASKWIDTH];	/* Packets in RecvLastContig+1..RecvMostRecent that I have received */
+    unsigned int RecvTheseBits[BITMASKWIDTH];	/* Packets in RecvLastContig+1..RecvMostRecent that I have received */
     RPC2_PacketBuffer *ThesePackets[MAXOPACKETS];
     /* Packets being currently dealt with. There can be at most MAXOPACKETS
      * outstanding, in the range LastContig+1..LastContig+WindowSize. The
@@ -302,6 +301,7 @@ struct SFTP_Entry		/* per-connection data structure */
      * Sending side: The packets have been sent, and an ACK for them has been
      * received.
      */
+    struct security_association *sa;
     };
 
 
@@ -392,9 +392,6 @@ void sftp_Progress(SE_Descriptor *sdesc, off_t BytesTransferred);
 
 void sftp_UpdateRTT(RPC2_PacketBuffer *pb, struct SFTP_Entry *sEntry,
 		    unsigned long inbytes, unsigned long outbytes);
-int SFXlateMcastPacket(RPC2_PacketBuffer *pb);
-int MC_CheckAckorNak(struct SFTP_Entry *whichEntry);
-int MC_CheckStart(struct SFTP_Entry *whichEntry);
 
 struct SFTP_Entry *sftp_AllocSEntry(void);
 void sftp_FreeSEntry(struct SFTP_Entry *se);
