@@ -196,6 +196,7 @@ long SFTP_Bind1(IN ConnHandle, IN ClientIdent)
     se = sftp_AllocSEntry();	/* malloc and initialize SFTP_Entry */
     se->WhoAmI = SFCLIENT;
     se->LocalHandle = ConnHandle;
+    se->sa = rpc2_GetSA(ConnHandle);
     RPC2_SetSEPointer(ConnHandle, se);
     return(RPC2_SUCCESS);
     }
@@ -267,6 +268,7 @@ long SFTP_NewConn(IN ConnHandle, IN ClientIdent)
     se->HostInfo = rpc2_GetHost(se->PInfo.RemoteHost.Value.AddrInfo);
     assert(se->HostInfo);
 
+    se->sa = rpc2_GetSA(ConnHandle);
     RPC2_SetSEPointer(ConnHandle, se);
 
     return(RPC2_SUCCESS);    
@@ -293,7 +295,6 @@ long SFTP_MakeRPC1(IN ConnHandle, INOUT SDesc, INOUT RequestPtr)
     sftp_Progress(SDesc, 0);
 
     se->XferState = XferNotStarted;
-    se->UseMulticast = FALSE;
     se->HitEOF = FALSE;
     if (SDesc->Value.SmartFTPD.TransmissionDirection == CLIENTTOSERVER)
 	{
@@ -895,7 +896,7 @@ static RPC2_PacketBuffer *AwaitPacket(struct timeval *tOut,
 {
     struct SL_Entry *sl;
 
-    if (LWP_GetRock(SMARTFTP, (char **)&sl) != LWP_SUCCESS)
+    if (LWP_GetRock(SMARTFTP, (void *)&sl) != LWP_SUCCESS)
     {
 	sl = rpc2_AllocSle(OTHER, NULL);
 	assert(LWP_NewRock(SMARTFTP, (char *)sl) == LWP_SUCCESS);
@@ -939,8 +940,9 @@ static long MakeBigEnough(RPC2_PacketBuffer **whichP, off_t extraBytes,
     /* Realloc and copy */
     assert(extraBytes <= INT_MAX); /* LFS */
     RPC2_AllocBuffer(extraBytes + (*whichP)->Header.BodyLength, &pb);
-    pb->Header.BodyLength = (*whichP)->Header.BodyLength;
+    //pb->Header.BodyLength = (*whichP)->Header.BodyLength;
     memcpy(&pb->Header, &(*whichP)->Header, curlen);
+    pb->Prefix.sa = (*whichP)->Prefix.sa;
     *whichP = pb;	/* DON'T free old packet !!! */
     return(0);
 }
