@@ -95,11 +95,11 @@ static int sftp_vfwritev(struct SFTP_Entry *se, struct iovec *iovarray, long how
 static int sftp_vfreadv(struct SFTP_Entry *se, struct iovec iovarray[], long howMany);
 
 /* sftp5.c */
-extern void B_ShiftLeft();
-extern void B_ShiftRight();
-extern void B_Assign();
-extern void B_CopyToPacket();
-extern void B_CopyFromPacket();
+void B_ShiftLeft(unsigned int *bMask, int bShift);
+void B_ShiftRight(unsigned int *bMask, int bShift);
+void B_Assign(unsigned int *dest, unsigned int *src);
+void B_CopyToPacket(unsigned int *bMask, RPC2_PacketBuffer *whichPacket);
+void B_CopyFromPacket(RPC2_PacketBuffer *whichPacket, unsigned int *bMask);
 
 #ifdef RPC2DEBUG
 void PrintDb(struct SFTP_Entry *se, RPC2_PacketBuffer *pb);
@@ -267,10 +267,8 @@ int sftp_DataArrived(RPC2_PacketBuffer *pBuff, struct SFTP_Entry *sEntry)
 	sEntry->SentParms = TRUE;    /* this data packet is evidence that my Start got to the client */
 
     sftp_datar++;
-    if (IsMulticast(pBuff))
-	sftp_MRecvd.Datas++;
-    else
-	sftp_Recvd.Datas++;
+    sftp_Recvd.Datas++;
+
     say(/*9*/4, SFTP_DebugLevel, "R-%u [%u] {%d} %s%s\n", pBuff->Header.SeqNumber, 
 				  pBuff->Header.TimeStamp, pBuff->Header.TimeEcho,
 				  (pBuff->Header.SEFlags & SFTP_FIRST)?"F":"",
@@ -302,10 +300,8 @@ int sftp_DataArrived(RPC2_PacketBuffer *pBuff, struct SFTP_Entry *sEntry)
 	/* we have already seen this packet */
 	sftp_duplicates++;
 	sEntry->DupsSinceAck++;
-	if (IsMulticast(pBuff))
-	    sftp_MRecvd.DataRetries++;
-	else
-	    sftp_Recvd.DataRetries++;
+	sftp_Recvd.DataRetries++;
+
 	if (((pBuff->Header.Flags & SFTP_ACKME) && sEntry->WhoAmI == SFCLIENT)
 	    || sEntry->DupsSinceAck > sEntry->DupThreshold) {
 	    /* we already saw this packet, so this must be considered
@@ -423,10 +419,9 @@ int sftp_WriteStrategy(struct SFTP_Entry *sEntry)
 {
     RPC2_PacketBuffer *pb;
     struct iovec iovarray[MAXOPACKETS];
-    long i, iovlen, mcastlen, bytesnow;
+    long i, iovlen, bytesnow;
     
     iovlen = 0;
-    mcastlen = 0;
     bytesnow = 0;
     for (i = 1; i < MAXOPACKETS+1; i++) {
 	long x;
@@ -442,44 +437,29 @@ int sftp_WriteStrategy(struct SFTP_Entry *sEntry)
 	    (x + pb->Header.BodyLength) > 
 	    sEntry->SDesc->Value.SmartFTPD.ByteQuota) {
 	    sEntry->SDesc->Value.SmartFTPD.QuotaExceeded = 1;
-	    iovarray[i-1].iov_len = 
-		sEntry->SDesc->Value.SmartFTPD.ByteQuota - x; 
+	    iovarray[i-1].iov_len =
+		sEntry->SDesc->Value.SmartFTPD.ByteQuota - x;
 	    /* may result in 0 len for trailing packets after the
 	       one exceeding the quota */
-	} else 
+	} else
 	    iovarray[i-1].iov_len = pb->Header.BodyLength;
 
 	bytesnow += iovarray[i-1].iov_len;
 	iovlen++;
-	if (pb->Header.Flags & RPC2_MULTICAST) 
-	    mcastlen++;
     }
-    if (iovlen == 0) 
+    if (iovlen == 0)
 	return(0);  /* 0-length initial run of packets */
-    
+
     if (!(bytesnow == sftp_vfwritev(sEntry, iovarray, iovlen))) {
 	sftp_SetError(sEntry, DISKERROR);	/* probably disk full */
 	return(-1);
     }
-    
-    for (i = sEntry->RecvLastContig + 1; 
+
+    for (i = sEntry->RecvLastContig + 1;
 	 i < sEntry->RecvLastContig + iovlen + 1; i++)
 	SFTP_FreeBuffer(&sEntry->ThesePackets[PBUFF(i)]);
     sEntry->RecvLastContig += iovlen;
-    B_ShiftLeft((unsigned int *)sEntry->RecvTheseBits, iovlen);
-
-    /* update the multicast state */
-    assert(mcastlen == iovlen || mcastlen == 0);
-    if (mcastlen != 0) {
-	struct CEntry		*ce;
-	struct MEntry		*me;
-	struct SFTP_Entry	*mse;
-
-	assert((ce = rpc2_GetConn(sEntry->LocalHandle)) != NULL);
-	assert((me = ce->Mgrp) != NULL);
-	assert((mse = (struct SFTP_Entry *)me->SideEffectPtr) != NULL);
-	mse->RecvLastContig += mcastlen;
-    }
+    B_ShiftLeft(sEntry->RecvTheseBits, iovlen);
 
     sftp_Progress(sEntry->SDesc,
                   sEntry->SDesc->Value.SmartFTPD.BytesTransferred + bytesnow);
@@ -496,7 +476,7 @@ static void sftp_SendAck(struct SFTP_Entry *sEntry)
 {
     RPC2_PacketBuffer *pb;
     long i, shiftlen;
-    unsigned long btemp[BITMASKWIDTH], now;
+    unsigned int btemp[BITMASKWIDTH], now;
     int confirm = 1;
     
     sftp_acks++;
@@ -525,8 +505,8 @@ static void sftp_SendAck(struct SFTP_Entry *sEntry)
 	confirm = 0;
     }
 
-    B_Assign((unsigned int *)btemp, (unsigned int *)sEntry->RecvTheseBits);
-    
+    B_Assign(btemp, sEntry->RecvTheseBits);
+
     /* Bump GotEmAll here; this allows write to disk to occur after ack is sent */
     shiftlen = 0;
     for (i = 1; i <= sEntry->WindowSize ; i++)
@@ -536,8 +516,8 @@ static void sftp_SendAck(struct SFTP_Entry *sEntry)
 	    shiftlen++;
 	    }
 	else break;
-    if (shiftlen > 0) B_ShiftLeft((unsigned int *)btemp, shiftlen);
-    B_CopyToPacket((unsigned int *)btemp, pb);
+    if (shiftlen > 0) B_ShiftLeft(btemp, shiftlen);
+    B_CopyToPacket(btemp, pb);
     rpc2_htonp(pb);
     sftp_XmitPacket(sEntry, pb, confirm);
     sEntry->RecvSinceAck = 0;
@@ -637,14 +617,7 @@ int sftp_AckArrived(RPC2_PacketBuffer *pBuff, struct SFTP_Entry *sEntry)
 
     /* Update counters to match other side */
     sEntry->SendLastContig = pBuff->Header.GotEmAll;
-    B_CopyFromPacket(pBuff, (unsigned int *)sEntry->SendTheseBits);
-
-    /* Handle multicast STOREs here */
-    if (sEntry->UseMulticast)
-	{
-	assert(sEntry->SDesc->Value.SmartFTPD.TransmissionDirection == CLIENTTOSERVER);
-	return(MC_CheckAckorNak(sEntry));
-	}
+    B_CopyFromPacket(pBuff, sEntry->SendTheseBits);
 
     /* Release prefix sequence of packets received by other side */
     /* acked non-prefix packets are still kept, even though not needed */
@@ -652,8 +625,8 @@ int sftp_AckArrived(RPC2_PacketBuffer *pBuff, struct SFTP_Entry *sEntry)
 	SFTP_FreeBuffer(&sEntry->ThesePackets[PBUFF((sEntry->SendLastContig - i))]);
 
     /* Do we have more work to do? */
-    if (sEntry->HitEOF && sEntry->ReadAheadCount == 0 
-	    && sEntry->SendMostRecent == sEntry->SendLastContig)
+    if (sEntry->HitEOF && sEntry->ReadAheadCount == 0 &&
+	sEntry->SendMostRecent == sEntry->SendLastContig)
 	{/* I have nothing more to send, and peer has seen all I have sent */
 	sEntry->XferState = XferCompleted;
 	return(0);
@@ -861,28 +834,22 @@ static int ResendWorried(struct SFTP_Entry *sEntry)
 		pb->Header.Flags &= ~SFTP_ACKME;
 	    } else {
 		/* Demand ack for first of the worried set */
-	    	pb->Header.Flags |= SFTP_ACKME;
+		pb->Header.Flags |= SFTP_ACKME;
 		acked = 1;
 	    }
-	    if (i == sEntry->SendLastContig+1) 
+	    if (i == sEntry->SendLastContig+1)
 	        {/* first packet */
 		pb->Header.SEFlags = ntohl(pb->Header.SEFlags);
 		pb->Header.SEFlags |= SFTP_FIRST;
 		pb->Header.SEFlags = htonl(pb->Header.SEFlags);
 	        }
 	    pb->Header.Flags |= RPC2_RETRY;
-	    if (IsMulticast(pb))
-		{
-		sftp_MSent.Datas++;
-		sftp_MSent.DataRetries++;
-		}
-	    else
-		{
-		sftp_Sent.Datas++;
-		sftp_Sent.DataRetries++;
-		}
+
+	    sftp_Sent.Datas++;
+	    sftp_Sent.DataRetries++;
 	    sftp_datas++;
 	    sftp_retries++;
+
 	    pb->Header.Flags = htonl(pb->Header.Flags);
 
 	    now = rpc2_MakeTimeStamp();
@@ -913,7 +880,7 @@ static int SendFirstUnacked(struct SFTP_Entry *sEntry)
     /* Note: it's better to resend the first unacked rather than last
        unacked, because it will narrow the window faster than the
        latter */
-	
+
     RPC2_PacketBuffer *pb;
     unsigned long now;
 
@@ -926,18 +893,12 @@ static int SendFirstUnacked(struct SFTP_Entry *sEntry)
     pb->Header.Flags |= SFTP_ACKME | RPC2_RETRY;
     pb->Header.SEFlags = ntohl(pb->Header.SEFlags);
     pb->Header.SEFlags |= SFTP_FIRST;
-    if (IsMulticast(pb))
-	{
-	sftp_MSent.Datas++;
-	sftp_MSent.DataRetries++;
-	}
-    else
-	{
-	sftp_Sent.Datas++;
-	sftp_Sent.DataRetries++;
-	}
+
+    sftp_Sent.Datas++;
+    sftp_Sent.DataRetries++;
     sftp_datas++;
     sftp_retries++;
+
     pb->Header.Flags = htonl(pb->Header.Flags);
     pb->Header.SEFlags = htonl(pb->Header.SEFlags);
 
@@ -1008,10 +969,7 @@ static int SendSendAhead(struct SFTP_Entry *sEntry, int worried)
 	    pb->Header.SEFlags |= SFTP_FIRST;
 	    pb->Header.SEFlags = htonl(pb->Header.SEFlags);
 	    }
-	if (ntohl(pb->Header.Flags) & RPC2_MULTICAST)
-	    sftp_MSent.Datas++;
-	else
-	    sftp_Sent.Datas++;
+	sftp_Sent.Datas++;
 	sftp_datas++;
 
 	now = rpc2_MakeTimeStamp();
@@ -1033,31 +991,6 @@ static int SendSendAhead(struct SFTP_Entry *sEntry, int worried)
 		(unsigned long)ntohl(pb->Header.TimeEcho));
 	}
 
-    /* if we are multicasting, update the per-connection
-       SendMostRecent markers */
-    /* note: we assume that sEntry here is the MULTICAST descriptor */
-    if (sEntry->UseMulticast)
-	{
-	struct MEntry		*me;
-	struct SFTP_Entry	*mse, *thisse;
-	struct CEntry		*thisce;
-	int			host;
-
-	me = rpc2_GetMgrp(NULL, sEntry->PInfo.RemoteHandle, CLIENT);
-	assert(me);
-	mse = (struct SFTP_Entry *)me->SideEffectPtr;
-	assert(mse);
-	assert(mse == sEntry);			/* paranoia */
-
-	for (host = 0; host < me->howmanylisteners; host++)
-	    {
-	    assert((thisce = me->listeners[host]) != NULL);
-	    assert((thisse = (struct SFTP_Entry *)thisce->SideEffectPtr) != NULL);
-	    if (TestState(thisce, CLIENT, ~C_HARDERROR) && thisse->WhoAmI == SFCLIENT)
-		thisse->SendMostRecent += mse->ReadAheadCount;
-	    }
-	}
-
     sEntry->ReadAheadCount = 0;  /* we have eaten all of them */
     return(0);
 }
@@ -1087,7 +1020,7 @@ int sftp_ReadStrategy(struct SFTP_Entry *sEntry)
 	{
 	SFTP_AllocBuffer(bodylength, &pb);
 	sftp_InitPacket(pb, sEntry, bodylength);	/* BodyLength set */
-	pb->Header.Flags = (sEntry->UseMulticast ? RPC2_MULTICAST : 0);
+	pb->Header.Flags = 0;
 	pb->Header.SEFlags = SFTP_MOREDATA;		/* tentative assumption */
 	pb->Header.Opcode = SFTP_DATA;
 	pb->Header.SeqNumber = sEntry->SendMostRecent + i;
@@ -1118,68 +1051,42 @@ int sftp_ReadStrategy(struct SFTP_Entry *sEntry)
     /* Update BytesTransferred field */
     sftp_Progress(sEntry->SDesc,
                   sEntry->SDesc->Value.SmartFTPD.BytesTransferred + bytesread);
-    /* if we are multicasting, update the per-connection byte-transfer counts */
-    /* note: we assume that sEntry here is the MULTICAST descriptor */
-    if (sEntry->UseMulticast)
-	{
-	struct MEntry		*me;
-	struct SFTP_Entry	*mse, *thisse;
-	struct CEntry		*thisce;
-	SE_Descriptor		*thisdesc;
-	int			host;
-
-	me = rpc2_GetMgrp(NULL, sEntry->PInfo.RemoteHandle, CLIENT);
-	assert(me);
-	mse = (struct SFTP_Entry *)me->SideEffectPtr;
-	assert(mse);
-	assert(mse == sEntry);			/* paranoia */
-
-	for (host = 0; host < me->howmanylisteners; host++)
-	    {
-	    assert((thisce = me->listeners[host]) != NULL);
-	    assert((thisse = (struct SFTP_Entry *)thisce->SideEffectPtr) != NULL);
-	    if (TestState(thisce, CLIENT, ~C_HARDERROR) && thisse->WhoAmI == SFCLIENT)
-		{
-		assert((thisdesc = thisse->SDesc) != NULL);
-                sftp_Progress(thisdesc, bytesread +
-                              thisdesc->Value.SmartFTPD.BytesTransferred);
-		}
-	    }
-	}
     
     /* Did we hit EOF? */
     if (bytesread == byteswanted)
-	{/* EOF not seen yet */
+    {/* EOF not seen yet */
 	sEntry->ReadAheadCount = sEntry->SendAhead;
-	if (sEntry->PInfo.SecurityLevel == RPC2_SECURE)
+	if (!sEntry->sa->encrypt && sEntry->PInfo.SecurityLevel == RPC2_SECURE)
+	{
 	    /* Encrypt all packets here */
 	    for (i = 1; i < 1 + sEntry->SendAhead; i++)
-		{
+	    {
 		j = PBUFF((sEntry->SendMostRecent + i));
 		pb = sEntry->ThesePackets[j];
 		sftp_Encrypt(pb, sEntry);
 		pb->Header.Flags = htonl(ntohl(pb->Header.Flags) | RPC2_ENCRYPTED);
-		}
-	return(0);
+	    }
 	}
+	return(0);
+    }
     
     /* Alas, we did  */
     sEntry->HitEOF = TRUE;
     for (i = 1; i < sEntry->SendAhead + 1; i++)
-	{
+    {
 	if (bytesread > iovarray[i-1].iov_len)
-	    {
+	{
 	    bytesread -= iovarray[i-1].iov_len;
-	    if (sEntry->PInfo.SecurityLevel == RPC2_SECURE)
-		{
+	    if (!sEntry->sa->encrypt && sEntry->PInfo.SecurityLevel == RPC2_SECURE)
+	    {
 		/* encrypt packet */
 		j = PBUFF((sEntry->SendMostRecent + i));
 		pb = sEntry->ThesePackets[j];
 		sftp_Encrypt(pb, sEntry);
 		pb->Header.Flags |= RPC2_ENCRYPTED;
-	    	}
-	    continue;
 	    }
+	    continue;
+	}
 
 	/* this is the packet with the last data byte */
 	pb = sEntry->ThesePackets[PBUFF((sEntry->SendMostRecent + i))];
@@ -1189,13 +1096,13 @@ int sftp_ReadStrategy(struct SFTP_Entry *sEntry)
 	pb->Header.Flags |= SFTP_ACKME;	/* first transmission of last packet always acked */
 	pb->Prefix.LengthOfPacket = sizeof(struct RPC2_PacketHeader) + bytesread;
 	rpc2_htonp(pb);
-	if (sEntry->PInfo.SecurityLevel == RPC2_SECURE)
-	    {
+	if (!sEntry->sa->encrypt && sEntry->PInfo.SecurityLevel == RPC2_SECURE)
+	{
 	    sftp_Encrypt(pb, sEntry);
 	    pb->Header.Flags = htonl(ntohl(pb->Header.Flags) | RPC2_ENCRYPTED);
-	    }
-	break;
 	}
+	break;
+    }
 	
     sEntry->ReadAheadCount = i;
     /* release excess packets */
@@ -1305,12 +1212,6 @@ int sftp_StartArrived(RPC2_PacketBuffer *pBuff, struct SFTP_Entry *sEntry)
     
     sEntry->XferState = XferInProgress;
 
-    if (sEntry->UseMulticast)
-	{
-	assert(sftpd->TransmissionDirection == CLIENTTOSERVER);
-	return(MC_CheckStart(sEntry));
-	}
-
     return(sftp_SendStrategy(sEntry));
 }
 
@@ -1347,12 +1248,13 @@ void sftp_InitPacket(RPC2_PacketBuffer *pb, struct SFTP_Entry *sfe,
     pb->Prefix.LengthOfPacket = sizeof(struct RPC2_PacketHeader) + bodylen;
     pb->Prefix.RecvStamp.tv_sec = pb->Prefix.RecvStamp.tv_usec = 0;
     if (sfe)
-    	{
+    {
+	pb->Prefix.sa = sfe->sa;
 	pb->Header.RemoteHandle = sfe->PInfo.RemoteHandle;
 	pb->Header.LocalHandle = sfe->LocalHandle;
 	pb->Header.SubsysId = SMARTFTP;
 	pb->Header.ThisRPCCall = sfe->ThisRPCCall;
-    	}
+    }
 }
 
 
